@@ -30,6 +30,18 @@ for (window = gamgi->window_start; window != NULL; window = window->next)
   gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
 }
 
+void gamgi_global_selection_layer (void)
+{
+gamgi_window *window;
+
+/***********************************************************
+ * for all windows: set current layer as new current layer *
+ ***********************************************************/
+
+for (window = gamgi->window_start; window != NULL; window = window->next)
+  gamgi_gtk_object_layer_local (window->layer, window);
+}
+
 void gamgi_global_selection_undo (void)
 {
 gamgi_window *window;
@@ -88,10 +100,18 @@ GtkWidget *label;
 
 for (window = gamgi->window_start; window != NULL; window = window->next)
   {
+  /************************************************************
+   * listed gamgi windows might have an undefined gtk window, *
+   * as gtk windows are removed before window child objects   *
+   ************************************************************/
+
+  if (window->window == NULL) continue;
+
   button = (GtkWidget *) g_object_get_data (G_OBJECT (window->window), name);
   label = gtk_bin_get_child (GTK_BIN (button));
   gamgi_gtk_dialog_color_default (label, window);
   }
+
 }
 
 void gamgi_global_selection_link (gamgi_dlist *start)
@@ -174,4 +194,5 @@ if (selection != NULL)
   if (*start != NULL)
     gamgi_global_selection_remove (start, label);
   }
+
 }
