@@ -19,6 +19,7 @@
 #include "gamgi_engine_dlist.h"
 #include "gamgi_engine_copy.h"
 #include "gamgi_engine_link.h"
+#include "gamgi_engine_find.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
@@ -27,6 +28,16 @@
 #include "gamgi_math_vector.h"
 #include "gamgi_chem_bond.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
+
+enum { STATIC_LAYER, STATIC_LOCAL };
+
+static struct {
+gamgi_bool local;
+char name[GAMGI_ENGINE_TOKEN];
+int number;
+gamgi_layer *layer;
+double shift[3]; } cache;
 
 static gamgi_enum static_class (gamgi_window *window)
 {
@@ -35,7 +46,7 @@ GtkWidget *entry;
 GtkWidget *button;
 const char *name;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_assembly");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -53,6 +64,42 @@ gamgi_io_token_check (name) == FALSE) return GAMGI_ENGINE_ASSEMBLY;
 return GAMGI_ENGINE_LAYER;
 }
 
+static void static_default_layer (gamgi_window *window)
+{
+gamgi_object *object;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+char string[GAMGI_ENGINE_STRING];
+
+object = GAMGI_CAST_OBJECT window->layer;
+sprintf (string, "%s %d", object->name, object->number);
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
+gtk_entry_set_text (GTK_ENTRY (entry), string);
+}
+
+static void static_location (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+GtkWidget *combo;
+int row;
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_LAYER)
+  {
+  gtk_widget_set_sensitive (entry, TRUE);
+  static_default_layer (window);
+  }
+else
+  {
+  gtk_entry_set_text (GTK_ENTRY (entry), "");
+  gtk_widget_set_sensitive (entry, FALSE);
+  }
+}
+
 /**************** internal function ************
  *                                             *
  *                   STATIC_RESET              *
@@ -62,233 +109,27 @@ return GAMGI_ENGINE_LAYER;
 static void static_reset (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
-GtkEntry *entry;
+GtkWidget *entry;
+GtkWidget *combo;
+char string[GAMGI_ENGINE_TOKEN];
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_assembly");
-gtk_entry_set_text (entry, "");
-}
-
-/****************** internal function **************
- *                                                 *
- *                    STATIC_GLOBAL                *
- *                                                 *
- ***************************************************/
-
-static void static_global (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *hbox, *button;
-
-hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_assembly");
-
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
-  {
-  /********************************
-   * Choose the assembly directly *
-   ********************************/
-
-  gtk_widget_set_sensitive (hbox, TRUE);
-  }
-else
-  {
-  /*********************************************
-   * Choose the assemblies previously selected *
-   *********************************************/
-
-  static_reset (window);
-  gtk_widget_set_sensitive (hbox, FALSE);
-  }
-}
-
-static void static_copy (gamgi_assembly *assembly, gamgi_layer *layer,
-int number, double *shift, gamgi_window *window_dialog)
-{
-gamgi_window *window_mouse;
-gamgi_assembly *assembly_new = NULL;
-gamgi_dlist *atom_start;
-double translate[3];
-int i;
-
-/******************************************
- * Save destiny host layer as undo buffer *
- * layer, so it can be recovered later.   *
- ******************************************/
-
-gamgi_gtk_history_update (layer, layer->undo, GAMGI_ENGINE_UNDO);
-
-/***************************************************
- * get a list of all atoms in the scope object:    *
- * as only atoms can own bonds, this list gives    *
- * access to all bonds formed by the scope object. *
- *                                                 *
- * copy assemblys and their contents, cleaning the *
- * bonds formed with atoms that are not copied     *
- *                                                 *
- *  remove list of atoms used to clean the bonds   *
- ***************************************************/
-
-atom_start = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT assembly, NULL);
-
-/******************************
- * number must be 1 or higher *
- ******************************/
-
-gamgi_math_vector_zero (translate);
-for (i = 0; i < number; i++)
-  {
-  assembly_new = gamgi_engine_copy_assembly (assembly);
-  gamgi_engine_link_assembly_layer (assembly_new, layer);
-
-  /**************************************
-   * clean the bonds before translating *
-   **************************************/
-
-  gamgi_chem_bond_half_clean (atom_start);
-
-  gamgi_math_vector_add (translate, shift, translate);
-  gamgi_mesa_translate_assembly (assembly_new, translate);
-  }
-
-/************************
- * remove list of atoms *
- ************************/
-
-gamgi_engine_dlist_remove_all (atom_start);
- 
-/*****************************************
- * raise window containing layer to the  *
- * top and if layer is not on top, set   *
- * layer as the current layer and object *
- ******************************************/
-
-gamgi_gtk_object_copy (GAMGI_CAST_OBJECT assembly_new,
-GAMGI_CAST_OBJECT layer, window_dialog);
-
-/********************************************
- * Redraw gl_area image in window_mouse and *
- * reset the copy dialog in window_dialog   *
- ********************************************/
-
-window_mouse =  GAMGI_CAST_WINDOW layer->object.object;
-gtk_widget_queue_draw (window_mouse->area);
-
-static_reset (window_dialog);
-}
-
-/**************** internal function ************
- *                                             *
- *                    STATIC_OK                *
- *                                             *
+/***********************************************
+ * initialize assembly, name of copies, number *
+ * of copies, copies destination, copies shift *
  ***********************************************/
 
-static void static_ok (GtkWidget *widget, void *data)
-{
-gamgi_assembly *assembly;
-gamgi_layer *layer;
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *entry;
-const char *name;
-double shift[3];
-int number;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_assembly");
+gtk_entry_set_text (GTK_ENTRY (entry), "");
 
-/****************
- * get assembly *
- ****************/
-
-assembly = GAMGI_CAST_ASSEMBLY gamgi_gtk_object_name_number (dialog,
-"entry_assembly", GAMGI_ENGINE_ASSEMBLY, window);
-if (assembly == NULL)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid assembly object", window);
-  return;
-  }
- 
-/*************
- * get layer *
- *************/
-
-layer = GAMGI_CAST_LAYER gamgi_gtk_object_name_number (dialog,
-"entry_layer", GAMGI_ENGINE_LAYER, NULL);
-if (layer == NULL)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid layer object", window);
-  return;
-  }
-
-/**************
- * get number *
- **************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &number, 1, INT_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid number data", window);
-  return;
-  }
-
-/***************
- * get x shift *
- ***************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &shift[0], -DBL_MAX, DBL_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid shift data", window);
-  return;
-  }
-
-/***************
- * get y shift *
- ***************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &shift[1], -DBL_MAX, DBL_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid shift data", window);
-  return;
-  }
-
-/***************
- * get z shift *
- ***************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &shift[2], -DBL_MAX, DBL_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid shift data", window);
-  return;
-  }
-
-static_copy (assembly, layer, number, shift, window);
-}
-
-static void static_init (gamgi_window *window)
-{
-gamgi_object *object;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *entry;
-char string[2 * GAMGI_ENGINE_TOKEN];
-
-/************************************
- * initialize: number of copies,    *
- * copies destination, copies shift *
- ************************************/
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_name");
+gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
 sprintf (string, "%d", GAMGI_GTK_COPY_NUMBER);
 gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
-object = GAMGI_CAST_OBJECT window->layer;
-sprintf (string, "%s %d", object->name, object->number);
-gtk_entry_set_text (GTK_ENTRY (entry), string);
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_LAYER);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
 sprintf (string, "%f", GAMGI_GTK_COPY_X);
@@ -303,6 +144,362 @@ sprintf (string, "%f", GAMGI_GTK_COPY_Z);
 gtk_entry_set_text (GTK_ENTRY (entry), string);
 }
 
+/****************** internal function **************
+ *                                                 *
+ *                      STATIC_LIST                *
+ *                                                 *
+ ***************************************************/
+
+static void static_list (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *hbox;
+GtkWidget *button;
+GtkWidget *combo;
+gamgi_bool *sensitive;
+
+hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_assembly");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_location");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
+  {
+  /********************************
+   * Choose the assembly directly *
+   ********************************/
+
+  gtk_widget_set_sensitive (hbox, TRUE);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_LAYER);
+  sensitive[STATIC_LOCAL] = FALSE;
+  }
+else
+  {
+  /********************************************
+   * Choose the assemblys previously selected *
+   ********************************************/
+
+  static_reset (window);
+  gtk_widget_set_sensitive (hbox, FALSE);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_LAYER);
+  sensitive[STATIC_LOCAL] = TRUE;
+  }
+
+}
+
+static gamgi_bool static_grab (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+GtkWidget *button;
+const char *name;
+
+/********
+ * name *
+ ********/
+
+cache.name[0] = '\0';
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_name");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  if (gamgi_io_token_alpha_scan (name,
+  cache.name, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid copy name", window);
+    return FALSE;
+    }
+  }
+
+/**********
+ * number *
+ **********/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_int_scan (name, &cache.number, 1, INT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid copy number", window);
+  return FALSE;
+  }
+
+/*********
+ * layer *
+ *********/
+
+cache.layer = NULL;
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_layer");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  {
+  cache.layer = GAMGI_CAST_LAYER gamgi_gtk_object_name_number (dialog,
+  "entry_layer", GAMGI_ENGINE_LAYER, NULL);
+  if (cache.layer == NULL)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid copy location", window);
+    return FALSE;
+    }
+  }
+
+/***************
+ * x,y,z shift *
+ ***************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &cache.shift[0], -DBL_MAX, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid copy shift", window);
+  return FALSE;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &cache.shift[1], -DBL_MAX, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid copy shift", window);
+  return FALSE;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &cache.shift[2], -DBL_MAX, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid copy shift", window);
+  return FALSE;
+  }
+
+return TRUE;
+}
+
+static gamgi_bool static_apply (gamgi_assembly *assembly, gamgi_window *window)
+{
+gamgi_layer *layer;
+gamgi_assembly *assembly_new = NULL;
+gamgi_dlist *atom_start;
+double translate[3];
+int i;
+
+/*******************
+ * find host layer *
+ *******************/
+
+if (cache.layer == NULL)
+  layer = gamgi_engine_find_layer (GAMGI_CAST_OBJECT assembly);
+else
+  layer = cache.layer;
+
+/***************************************************
+ * get a list of all atoms in the scope object:    *
+ * as only atoms can own bonds, this list gives    *
+ * access to all bonds formed by the scope object. *
+ *                                                 *
+ * copy assemblys and their contents, cleaning the *
+ * bonds formed with atoms that are not copied     *
+ *                                                 *
+ *  remove list of atoms used to clean the bonds   *
+ ***************************************************/
+
+atom_start = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT assembly, NULL);
+
+if (cache.local == TRUE)
+  gamgi_gtk_history_update (layer, layer->undo, GAMGI_ENGINE_UNDO);
+
+gamgi_math_vector_zero (translate);
+for (i = 0; i < cache.number; i++)
+  {
+  assembly_new = gamgi_engine_copy_assembly (assembly);
+  if (cache.name[0] != '\0')
+    strcpy (assembly_new->object.name, cache.name);
+
+  gamgi_engine_link_assembly_layer (assembly_new, layer);
+
+  /**************************************
+   * clean the bonds before translating *
+   **************************************/
+
+  gamgi_chem_bond_half_clean (atom_start);
+
+  gamgi_math_vector_add (translate, cache.shift, translate);
+  gamgi_mesa_translate_assembly (assembly_new, translate);
+  }
+
+/************************
+ * remove list of atoms *
+ ************************/
+
+gamgi_engine_dlist_remove_all (atom_start);
+
+return TRUE;
+}
+
+static void static_ok_global (gamgi_window *window_dialog)
+{
+gamgi_window *window_mouse;
+gamgi_layer *layer;
+gamgi_object *object;
+gamgi_dlist *dlist;
+
+cache.local = FALSE;
+
+/********************************
+ * get object list, dialog data *
+ ********************************/
+
+if (gamgi->assemblys == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of assembly objects", window_dialog); return; }
+
+if (static_grab (window_dialog) == FALSE) return;
+
+/******************************************
+ * Save destiny host layer as undo buffer *
+ * layer, so it can be recovered later.   *
+ ******************************************/
+
+layer = cache.layer;
+if (layer == NULL)
+  {
+  /***********************************************
+   * For all windows: save layers as undo layers *
+   * and set current layer as new current object *
+   ***********************************************/
+
+  gamgi_global_selection_undo ();
+  gamgi_global_selection_focus ();
+  }
+else
+  {
+  /******************************************
+   * Save destiny host layer as undo buffer *
+   * layer, so it can be recovered later.   *
+   ******************************************/
+
+  gamgi_gtk_history_update (layer, layer->undo, GAMGI_ENGINE_UNDO);
+  }
+
+/*******************************************
+ * copy assemblys according to dialog data *
+ *******************************************/
+
+for (dlist = gamgi->assemblys; dlist != NULL; dlist = dlist->next)
+  static_apply (GAMGI_CAST_ASSEMBLY dlist->data, window_dialog);
+
+if (layer == NULL)
+  {
+  /*****************************************
+   * For all windows: redraw gl_area image *
+   ****************************************/
+
+  gamgi_global_selection_draw ();
+  }
+else
+  {
+  /*****************************************
+   * raise window containing layer to the  *
+   * top and if layer is not on top, set   *
+   * layer as the current layer and object *
+   *                                       *
+   * any assembly object can be used here  *
+   *****************************************/
+
+  object = GAMGI_CAST_OBJECT gamgi->assemblys->data;
+  gamgi_gtk_object_copy (object, GAMGI_CAST_OBJECT layer, window_dialog);
+
+  /********************************************
+   * Redraw gl_area image in window_mouse and *
+   * reset the copy dialog in window_dialog   *
+   ********************************************/
+
+  window_mouse =  GAMGI_CAST_WINDOW layer->object.object;
+  gtk_widget_queue_draw (window_mouse->area);
+  }
+
+static_reset (window_dialog);
+}
+
+static void static_ok_local (gamgi_window *window_dialog)
+{
+gamgi_window *window_mouse;
+gamgi_layer *layer;
+gamgi_assembly *assembly;
+GtkWidget *dialog = window_dialog->dialog0;
+
+cache.local = TRUE;
+
+/********************************
+ * pick object, get dialog data *
+ ********************************/
+
+assembly = GAMGI_CAST_ASSEMBLY gamgi_gtk_object_name_number (dialog,
+"entry_assembly", GAMGI_ENGINE_ASSEMBLY, window_dialog);
+if (assembly == NULL)
+  {
+  gamgi_gtk_dialog_message_create ("Error",
+  "Invalid assembly object", window_dialog);
+  return;
+  }
+
+if (static_grab (window_dialog) == FALSE) return;
+
+/******************************************
+ * copy assembly according to dialog data *
+ ******************************************/
+
+static_apply (assembly, window_dialog);
+
+/******************************************
+ * get and save host layer as undo buffer *
+ * layer, so it can be recovered later.   *
+ ******************************************/
+
+if (cache.layer == NULL)
+  layer = gamgi_engine_find_layer (GAMGI_CAST_OBJECT assembly);
+else
+  layer = cache.layer;
+
+/*****************************************
+ * raise window containing layer to the  *
+ * top and if layer is not on top, set   *
+ * layer as the current layer and object *
+ *****************************************/
+
+gamgi_gtk_object_copy (GAMGI_CAST_OBJECT assembly,
+GAMGI_CAST_OBJECT layer, window_dialog);
+
+/********************************************
+ * Redraw gl_area image in window_mouse and *
+ * reset the copy dialog in window_dialog   *
+ ********************************************/
+
+window_mouse =  GAMGI_CAST_WINDOW layer->object.object;
+gtk_widget_queue_draw (window_mouse->area);
+
+static_reset (window_dialog);
+}
+
+static void static_ok (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget* button;
+
+/*******************************************
+ * copy data: execute global or local task *
+ *******************************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (window);
+else
+  static_ok_local (window);
+}
+
+static void static_init (gamgi_window *window)
+{
+static_reset (window);
+static_list (NULL, window);
+}
+
 static void static_press (gamgi_object *object, void *data)
 {
 gamgi_window *window_dialog = gamgi->window_dialog;
@@ -312,7 +509,7 @@ GtkWidget *entry;
 char string[2 * GAMGI_ENGINE_TOKEN];
 const char *name;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_assembly");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -340,11 +537,17 @@ GtkWidget *entry;
 const char *name;
 
 /***********************************************
+ * local location is active only in List mode, *
+ * so objects and locations are already known  *
+ *                                             *
  * global selection can be used only to select *
- * the second object, not the main object(s)   *
+ * the location, the object to copy is local   *
  ***********************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_local");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE) return;
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_assembly");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -379,6 +582,11 @@ GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
+GtkWidget *combo;
+GtkListStore *store;
+GtkCellRenderer *renderer;
+GtkTreeIter iter;
+gamgi_bool *sensitive;
 
 /******************
  * dialog level 0 *
@@ -428,15 +636,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_assembly", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
@@ -449,12 +657,12 @@ gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
-/*************
- * Copy page *
- *************/
+/***************
+ * Object page *
+ ***************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new ("Copies");
+label = gtk_label_new ("Object");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
 gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
@@ -463,36 +671,55 @@ vbox_center = gtk_vbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
 gtk_widget_show (vbox_center);
 
-vbox_top = gtk_vbox_new (FALSE, 5);
+vbox_top = gtk_vbox_new (FALSE, 10);
 gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/**********
- * Number *
- **********/
+/****************
+ * Name, Number *
+ ****************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 5);
+hbox_left = gtk_hbox_new (FALSE, 10);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Number");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+label = gtk_label_new ("Name");
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
+g_object_set_data (G_OBJECT (dialog), "entry_name", entry);
+gtk_widget_show (entry);
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+label = gtk_label_new ("Number");
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_number", entry);
 gtk_widget_show (entry);
 
-/*********
- * Layer *
- *********/
+/************
+ * Location *
+ ************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
@@ -502,10 +729,34 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Layer");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+label = gtk_label_new ("Location");
+gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 5);
 gtk_widget_show (label);
 
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_signal_connect (combo, "changed",
+G_CALLBACK (static_location), window);
+g_object_set_data (G_OBJECT (dialog), "combo_location", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Layer", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Local", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+sensitive = gamgi_gtk_dialog_sensitive_create (2);
+g_object_set_data (G_OBJECT (dialog), "sensitive_location", sensitive);
+gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
+renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
+
 entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
