@@ -328,6 +328,113 @@ static_model (gamgi->atoms, window);
 static_method (NULL, window);
 }
 
+static gamgi_dlist *static_ok_name (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window)
+{
+gamgi_atom *atom;
+gamgi_dlist *dlist, *dlist_new;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+char name_min[GAMGI_ENGINE_TOKEN] = "";
+char name_max[GAMGI_ENGINE_TOKEN] = "";
+char swap[GAMGI_ENGINE_TOKEN] = "";
+const char *name;
+gamgi_bool condition;
+
+/********************
+ * get range limits *
+ ********************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "widget_min");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_alpha_scan (name,
+name_min, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid range limits", window);
+  return NULL;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "widget_max");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_alpha_scan (name,
+name_max, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid range limits", window);
+  return NULL;
+  }
+
+if (*name_min != '\0' && *name_max != '\0' && strcmp (name_min, name_max) > 0)
+  {
+  gamgi_gtk_dialog_message_create ("Warning", "Swapped range limits", window);
+
+  strcpy (swap, name_min);
+  strcpy (name_min, name_max);
+  strcpy (name_max, swap);
+  }
+
+/******************************
+ * get list of selected atoms *
+ ******************************/
+
+dlist_new = NULL;
+for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
+  {
+  atom = GAMGI_CAST_ATOM dlist->data;
+
+  condition = TRUE;
+  if (*name_min != '\0' && strcmp (atom->object.name, name_min) < 0)
+    condition = FALSE;
+  if (*name_max != '\0' && strcmp (atom->object.name, name_max) > 0)
+    condition = FALSE;
+
+  if (condition != action)
+    {
+    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
+    dlist_new->data = atom;
+    }
+  }
+
+return dlist_new;
+}
+
+static gamgi_dlist *static_ok_parent (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_enum class, gamgi_window *window)
+{
+gamgi_atom *atom;
+gamgi_object *parent;
+gamgi_dlist *dlist, *dlist_new;
+gamgi_bool condition;
+int min, max;
+
+/********************
+ * get range limits *
+ ********************/
+
+if (gamgi_gtk_select_entry_int (1, INT_MAX,
+&min, &max, window) == FALSE) return NULL;
+
+/******************************
+ * get list of selected atoms *
+ ******************************/
+
+dlist_new = NULL;
+for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
+  {
+  atom = GAMGI_CAST_ATOM dlist->data;
+  parent = atom->object.object;
+  condition = (parent->class == class &&
+  parent->number >= min && parent->number <= max);
+
+  if (condition != action)
+    {
+    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
+    dlist_new->data = atom;
+    }
+  }
+
+return dlist_new;
+}
+
 static gamgi_dlist *static_ok_element (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
@@ -1064,6 +1171,34 @@ if (strcmp (name, "Pick") == 0)
 else if (strcmp (name, "Region") == 0)
   dlist_new = gamgi_gtk_select_ok_region (dlist_old, action, window);
 
+else if (strcmp (name, "Name") == 0)
+  dlist_new = static_ok_name (dlist_old, action, window);
+
+else if (strcmp (name, "Layer") == 0)
+  dlist_new = static_ok_parent (dlist_old,
+  action, GAMGI_ENGINE_LAYER, window);
+else if (strcmp (name, "Assembly") == 0)
+  dlist_new = static_ok_parent (dlist_old,
+  action, GAMGI_ENGINE_ASSEMBLY, window);
+else if (strcmp (name, "Cell") == 0)
+  dlist_new = static_ok_parent (dlist_old,
+  action, GAMGI_ENGINE_CELL, window);
+else if (strcmp (name, "Cluster") == 0)
+  dlist_new = static_ok_parent (dlist_old,
+  action, GAMGI_ENGINE_CLUSTER, window);
+else if (strcmp (name, "Molecule") == 0)
+  dlist_new = static_ok_parent (dlist_old,
+  action, GAMGI_ENGINE_MOLECULE, window);
+else if (strcmp (name, "Group") == 0)
+  dlist_new = static_ok_parent (dlist_old,
+  action, GAMGI_ENGINE_GROUP, window);
+else if (strcmp (name, "Plane") == 0)
+  dlist_new = static_ok_parent (dlist_old,
+  action, GAMGI_ENGINE_PLANE, window);
+else if (strcmp (name, "Direction") == 0)
+  dlist_new = static_ok_parent (dlist_old,
+  action, GAMGI_ENGINE_DIRECTION, window);
+
 else if (strcmp (name, "Element") == 0)
   dlist_new = static_ok_element (dlist_old, action, window);
 else if (strcmp (name, "Number") == 0)
@@ -1496,6 +1631,28 @@ gtk_tree_store_set (tree_store, &iter, 0, "Pick", -1);
 gtk_tree_store_append (tree_store, &iter, NULL);
 gtk_tree_store_set (tree_store, &iter, 0, "Region", -1);
 
+gtk_tree_store_append (tree_store, &iter, NULL);
+gtk_tree_store_set (tree_store, &iter, 0, "Name", -1);
+
+gtk_tree_store_append (tree_store, &iter, NULL);
+gtk_tree_store_set (tree_store, &iter, 0, "Parent", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Layer", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Assembly", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Cell", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Cluster", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Molecule", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Group", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Plane", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Direction", -1);
+
 gtk_tree_store_append (tree_store, &iter, NULL);
 gtk_tree_store_set (tree_store, &iter, 0, "Type", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
