@@ -25,22 +25,24 @@
 #include "gamgi_mesa_select.h"
 #include "gamgi_mesa_bond.h"
 #include "gamgi_io_token.h"
+#include "gamgi_io_error.h"
 #include "gamgi_global_selection.h"
 
 static struct {
+gamgi_bool local;
 gamgi_bool new[10];
-
 char name[GAMGI_ENGINE_TOKEN];
-
 float order;
 float covalency;
-
 void (*draw) (gamgi_bond *);
 float size;
-double scale;
-
 gamgi_bool color;
-float red, green, blue; } cache;
+float red, green, blue;
+double scale; } cache;
+
+enum { STATIC_NAME = 0, STATIC_ORDER, STATIC_COVALENCY, 
+STATIC_STYLE, STATIC_SIZE, STATIC_COLOR, STATIC_RED, STATIC_GREEN,
+STATIC_BLUE, STATIC_SCALE };
 
 static void static_color (GtkWidget *widget, void *data)
 {
@@ -217,19 +219,19 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 GtkWidget *combo;
 const char *name;
-int row, i = 0;
+int row;
 
 /********************
  * order, covalency *
  ********************/
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_ORDER] = FALSE;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_order");
 entry = gtk_bin_get_child (GTK_BIN (combo));
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_ORDER] = TRUE;
   if (gamgi_io_token_float_scan (name, &cache.order, 0, FLT_MAX) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid order data", window);
@@ -237,12 +239,12 @@ if (gamgi_io_token_check (name) == TRUE)
     }
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_COVALENCY] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_covalency");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_COVALENCY] = TRUE;
   if (gamgi_io_token_float_scan (name, &cache.covalency, 0.0, FLT_MAX) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid covalency data", window);
@@ -250,27 +252,27 @@ if (gamgi_io_token_check (name) == TRUE)
     }
   }
 
-/**********************
- * style, size, scale *
- **********************/
+/***************
+ * style, size *
+ ***************/
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_STYLE] = FALSE;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (row < 2)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_STYLE] = TRUE;
   if (row == GAMGI_MESA_WIRED - 1) cache.draw = gamgi_mesa_bond_draw_line;
   if (row == GAMGI_MESA_SOLID - 1) cache.draw = gamgi_mesa_bond_draw_cylinder;
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_SIZE] = FALSE;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
 entry = gtk_bin_get_child (GTK_BIN (combo));
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_SIZE] = TRUE;
   if (gamgi_io_token_float_scan (name, &cache.size, 0.0, FLT_MAX) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid size data", window);
@@ -278,40 +280,26 @@ if (gamgi_io_token_check (name) == TRUE)
     }
   }
 
-cache.new[++i] = FALSE;
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_check (name) == TRUE)
-  {
-  cache.new[i] = TRUE;
-  if (gamgi_io_token_double_scan (name, &cache.scale,
-  GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid scale data", window);
-    return FALSE;
-    }
-  }
-
-/***************************
- * color, red, green, blue *
- ***************************/
+/**********************************
+ * color, red, green, blue, scale *
+ **********************************/
    
-cache.new[++i] = FALSE;
+cache.new[STATIC_COLOR] = FALSE;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_color");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (row < 2)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_COLOR] = TRUE;
   if (row == GAMGI_GTK_YES - 1) cache.color = TRUE;
   if (row == GAMGI_GTK_NO - 1) cache.color = FALSE;
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_RED] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_RED] = TRUE;
   if (gamgi_io_token_float_scan (name,
   &cache.red, 0.0, 1.0) == FALSE)
     {
@@ -320,12 +308,12 @@ if (gamgi_io_token_check (name) == TRUE)
     }
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_GREEN] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_GREEN] = TRUE;
   if (gamgi_io_token_float_scan (name,
   &cache.green, 0.0, 1.0) == FALSE)
     {
@@ -334,12 +322,12 @@ if (gamgi_io_token_check (name) == TRUE)
     }
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_BLUE] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_BLUE] = TRUE;
   if (gamgi_io_token_float_scan (name,
   &cache.blue, 0.0, 1.0) == FALSE)
     {
@@ -348,17 +336,30 @@ if (gamgi_io_token_check (name) == TRUE)
     }
   }
 
+cache.new[STATIC_SCALE] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_SCALE] = TRUE;
+  if (gamgi_io_token_double_scan (name, &cache.scale,
+  GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid scale data", window);
+    return FALSE;
+    }
+  }
+
 return TRUE;
 }
 
-static gamgi_bool static_apply (gamgi_bond *bond, gamgi_bool local,
-gamgi_window *window)
+static gamgi_bool static_apply (gamgi_bond *bond, gamgi_window *window)
 {
 void (*draw) (gamgi_bond *);
 char name[GAMGI_ENGINE_TOKEN];
 double order, covalency, scale;
 float size, red, green, blue;
-int color, i = 0;
+gamgi_enum color;
 
 /*************************
  * import data from bond *
@@ -371,87 +372,69 @@ order = bond->order;
 
 draw = bond->draw;
 size = bond->size;
-scale = bond->object.scale;
 color = bond->color;
 red = bond->red;
 green = bond->green;
 blue = bond->blue;
+scale = bond->object.scale;
 
-/***************************************
- * set default size when style changes *
- ***************************************/
+/**********************************************
+ * set default: size,variancy when style      *
+ * changes; red,green,blue when color changes *
+ **********************************************/
 
-if (cache.new[3] == TRUE && cache.draw != bond->draw)
-  if (cache.new[4] == FALSE) size = gamgi->bond->size;
+if (cache.new[STATIC_STYLE] == TRUE && cache.draw != bond->draw)
+  if (cache.new[STATIC_SIZE] == FALSE) size = gamgi->bond->size;
 
-/*************************************************
- * set default red,green,blue when color changes *
- *************************************************/
-
-if (cache.new[6] == TRUE && cache.color != bond->color)
+if (cache.new[STATIC_COLOR] == TRUE && cache.color != bond->color)
   {
-  if (cache.new[7] == FALSE) red = gamgi->bond->red;
-  if (cache.new[8] == FALSE) green = gamgi->bond->green;
-  if (cache.new[9] == FALSE) blue = gamgi->bond->blue;
+  if (cache.new[STATIC_RED] == FALSE) red = gamgi->bond->red;
+  if (cache.new[STATIC_GREEN] == FALSE) green = gamgi->bond->green;
+  if (cache.new[STATIC_BLUE] == FALSE) blue = gamgi->bond->blue;
   }
 
 /******************
  * apply new data *
  ******************/
 
-if (cache.new[i++] == TRUE)
-  strcpy (name, cache.name);
+if (cache.new[STATIC_NAME] == TRUE) strcpy (name, cache.name);
 
-if (cache.new[i++] == TRUE)
-  order = cache.order;
-if (cache.new[i++] == TRUE)
-  covalency = cache.covalency;
+if (cache.new[STATIC_ORDER] == TRUE) order = cache.order;
+if (cache.new[STATIC_COVALENCY] == TRUE) covalency = cache.covalency;
 
-if (cache.new[i++] == TRUE)
-  draw = cache.draw;
-if (cache.new[i++] == TRUE)
+if (cache.new[STATIC_STYLE] == TRUE) draw = cache.draw;
+if (cache.new[STATIC_SIZE] == TRUE) size = cache.size;
+if (cache.new[STATIC_COLOR] == TRUE) color = cache.color;
+if (cache.new[STATIC_RED] == TRUE) red = cache.red;
+if (cache.new[STATIC_GREEN] == TRUE) green = cache.green;
+if (cache.new[STATIC_BLUE] == TRUE) blue = cache.blue;
+if (cache.new[STATIC_SCALE] == TRUE) scale = cache.scale;
+
+/****************************
+ * check data compatibility *
+ ****************************/
+
+if (draw == gamgi_mesa_bond_draw_line && cache.new[STATIC_SIZE] == TRUE)
   {
-  size = cache.size;
-  if (draw == gamgi_mesa_bond_draw_line)
-    {
-    if (local == TRUE)
-      gamgi_gtk_dialog_message_create ("Error", "Invalid size", window);
-    return FALSE;
-    }
+  /*************************************
+   * size is not defined in wired mode *
+   *************************************/
+
+  if (cache.local == TRUE)
+    gamgi_gtk_dialog_message_create ("Error", "Invalid size", window);
+  return FALSE;
   }
-if (cache.new[i++] == TRUE)
-  scale = cache.scale;
-if (cache.new[i++] == TRUE)
-  color = cache.color;
-if (cache.new[i++] == TRUE)
+
+if (color == FALSE && (cache.new[STATIC_RED] == TRUE ||
+cache.new[STATIC_GREEN] == TRUE || cache.new[STATIC_BLUE] == TRUE))
   {
-  red = cache.red;
-  if (color == FALSE)
-    {
-    if (local == TRUE)
-      gamgi_gtk_dialog_message_create ("Error", "Invalid color data", window);
-    return FALSE;
-    }
-  }
-if (cache.new[i++] == TRUE)
-  {
-  green = cache.green;
-  if (color == FALSE)
-    {
-    if (local == TRUE)
-      gamgi_gtk_dialog_message_create ("Error", "Invalid color data", window);
-    return FALSE;
-    }
-  }
-if (cache.new[i++] == TRUE)
-  {
-  blue = cache.blue;
-  if (color == FALSE)
-    {
-    if (local == TRUE)
-      gamgi_gtk_dialog_message_create ("Error", "Invalid color data", window);
-    return FALSE;
-    }
+  /****************************************************
+   * red,green,blue are not defined when color is off *
+   ****************************************************/
+
+  if (cache.local == TRUE)
+    gamgi_gtk_dialog_message_create ("Error", "Invalid color data", window);
+  return FALSE;
   }
 
 /***************************************
@@ -459,7 +442,7 @@ if (cache.new[i++] == TRUE)
  * layer so it can be recovered later. *
  ***************************************/
 
-if (local == TRUE)
+if (cache.local == TRUE)
   gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
 
 /*************************
@@ -473,25 +456,24 @@ bond->order = order;
 
 bond->draw = draw;
 bond->size = size;
-bond->object.scale = scale;
 bond->color = color;
 bond->red = red;
 bond->green = green;
 bond->blue = blue;
+bond->object.scale = scale;
 
 return TRUE;
 }
 
 static void static_ok_global (gamgi_window *window)
 {
-gamgi_object *object;
 gamgi_dlist *dlist;
-gamgi_slist *slist, *start;
+gamgi_slist *start;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 const char *name;
-char line[GAMGI_ENGINE_LINE];
-char string[GAMGI_ENGINE_STRING];
+
+cache.local = FALSE;
 
 if (gamgi->bonds == NULL)
   { gamgi_gtk_dialog_message_create ("Error",
@@ -501,12 +483,12 @@ if (gamgi->bonds == NULL)
  * Pick name (possibly new) *
  ****************************/
 
-cache.new[0] = FALSE;
+cache.new[STATIC_NAME] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_bond");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[0] = TRUE;
+  cache.new[STATIC_NAME] = TRUE;
   if (gamgi_io_token_alpha_scan (name,
   cache.name, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
     {
@@ -518,48 +500,26 @@ if (gamgi_io_token_check (name) == TRUE)
 if (static_grab (window) == FALSE) return;
 
 /************************************************
- * for all windows: save layers as undo layers, *
- * set current layer as new current object      *
+ * For all windows: save layers as undo layers  *
+ * and set current layer as new current object  *
+ *                                              *
+ * Modify listed objects and show error message *
+ * with objects that could not be modified      *
+ *                                              *
+ * For all windows: redraw gl_area image        *
  ************************************************/
 
 gamgi_global_selection_undo ();
 gamgi_global_selection_focus ();
 
-/*******************************************
- * modify bond data as specified in dialog *
- *******************************************/
-
 start = NULL;
 for (dlist = gamgi->bonds; dlist != NULL; dlist = dlist->next)
-  if (static_apply (GAMGI_CAST_BOND dlist->data, FALSE, window) == FALSE)
+  if (static_apply (GAMGI_CAST_BOND dlist->data, window) == FALSE)
     {
     start = gamgi_engine_slist_add_start (start);
     start->data = dlist->data;
     }
-
-if (start != NULL)
-  {
-  sprintf (line, "The following objects could not be modified:\n");
-
-  start = gamgi_engine_slist_invert (start);
-  for (slist = start; slist != NULL; slist = slist->next)
-    {
-    if (slist != start) strcat (line, ", ");
-
-    if (strlen (line) > GAMGI_ENGINE_LINE - GAMGI_ENGINE_STRING)
-      { strcat (line, "..."); break; }
-
-    object = GAMGI_CAST_OBJECT slist->data;
-    sprintf (string, "%s %d", object->name, object->number);
-    strcat (line, string);
-    }
-  gamgi_gtk_dialog_message_create ("Error", line, window);
-  gamgi_engine_slist_remove_all (start);
-  }
-
-/*****************************************
- * For all windows: redraw gl_area image *
- *****************************************/
+gamgi_io_error_list (start, window);
 
 gamgi_global_selection_draw ();
 
@@ -574,12 +534,17 @@ static void static_ok_local (gamgi_window *window)
 {
 gamgi_bond *bond;
 GtkWidget *dialog = window->dialog0;
+gamgi_bool focus;
 
-/*******************************************
- * Pick object and get name (possibly new) *
- *******************************************/
+cache.local = TRUE;
 
-cache.new[0] = TRUE;
+/*****************************************
+ * pick bond and get name (possibly new) *
+ *                                       *
+ * check if focus object belongs to bond *
+ *****************************************/
+
+cache.new[STATIC_NAME] = TRUE;
 bond = GAMGI_CAST_BOND gamgi_gtk_object_number (dialog,
 "entry_bond", GAMGI_ENGINE_BOND, window, cache.name);
 if (bond == NULL)
@@ -588,24 +553,29 @@ if (bond == NULL)
   return;
   }
 
+focus = FALSE;
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT bond) == TRUE) focus = TRUE;
+
+/********************************************
+ * collect data from dialog and modify bond *
+ ********************************************/
+
 if (static_grab (window) == FALSE) return;
+if (static_apply (bond, window) == FALSE) return;
 
-/*******************************************
- * modify bond data as specified in dialog *
- *******************************************/
+/*************************************************************
+ * when focus object is affected, change it to current layer *
+ *************************************************************/
 
-if (static_apply (bond, TRUE, window) == FALSE) return;
+if (focus == TRUE)
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
 
-/************************
- * Redraw gl_area image *
- ************************/
+/*****************************************
+ * redraw gl_area image and reset dialog *
+ *****************************************/
 
 gtk_widget_queue_draw (window->area);
-
-/****************
- * reset dialog *
- ****************/
-
 static_reset (window);
 }
 
