@@ -330,6 +330,75 @@ static_model (gamgi->bonds, window);
 static_method (NULL, window);
 }
 
+static gamgi_dlist *static_ok_name (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window)
+{
+gamgi_atom *atom;
+gamgi_dlist *dlist, *dlist_new;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+char name_min[GAMGI_ENGINE_TOKEN] = "";
+char name_max[GAMGI_ENGINE_TOKEN] = "";
+char swap[GAMGI_ENGINE_TOKEN] = "";
+const char *name;
+gamgi_bool condition;
+
+/********************
+ *  * get range limits *
+ *   ********************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "widget_min");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_alpha_scan (name,
+name_min, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid range limits", window);
+  return NULL;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "widget_max");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_alpha_scan (name,
+name_max, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid range limits", window);
+  return NULL;
+  }
+
+if (*name_min != '\0' && *name_max != '\0' && strcmp (name_min, name_max) > 0)
+  {
+  gamgi_gtk_dialog_message_create ("Warning", "Swapped range limits", window);
+
+  strcpy (swap, name_min);
+  strcpy (name_min, name_max);
+  strcpy (name_max, swap);
+  }
+
+/******************************
+ *  * get list of selected atoms *
+ *   ******************************/
+
+dlist_new = NULL;
+for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
+  {
+  atom = GAMGI_CAST_ATOM dlist->data;
+
+  condition = TRUE;
+  if (*name_min != '\0' && strcmp (atom->object.name, name_min) < 0)
+    condition = FALSE;
+  if (*name_max != '\0' && strcmp (atom->object.name, name_max) > 0)
+    condition = FALSE;
+
+  if (condition != action)
+    {
+    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
+    dlist_new->data = atom;
+    }
+  }
+
+return dlist_new;
+}
+
 static gamgi_dlist *static_ok_element (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
@@ -760,6 +829,9 @@ if (strcmp (name, "Pick") == 0)
 else if (strcmp (name, "Region") == 0)
   dlist_new = gamgi_gtk_select_ok_region (dlist_old, action, window);
 
+else if (strcmp (name, "Name") == 0)
+  dlist_new = static_ok_name (dlist_old, action, window);
+
 else if (strcmp (name, "Element") == 0)
   dlist_new = static_ok_element (dlist_old, action, window);
 
@@ -1155,6 +1227,9 @@ gtk_tree_store_set (tree_store, &iter, 0, "Pick", -1);
 gtk_tree_store_append (tree_store, &iter, NULL);
 gtk_tree_store_set (tree_store, &iter, 0, "Region", -1);
 
+gtk_tree_store_append (tree_store, &iter, NULL);
+gtk_tree_store_set (tree_store, &iter, 0, "Name", -1);
+
 gtk_tree_store_append (tree_store, &iter, NULL);
 gtk_tree_store_set (tree_store, &iter, 0, "Element", -1);
 
