@@ -13,16 +13,21 @@
 #include "gamgi_gtk.h"
 #include "gamgi_phys.h"
 #include "gamgi_io.h"
+#include "gamgi_math.h"
 #include "gamgi_global.h"
 
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
-#include "gamgi_gtk_cell_shift.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_phys_cell_link.h"
 #include "gamgi_phys_space.h"
+#include "gamgi_phys_plane.h"
+#include "gamgi_phys_direction.h"
 #include "gamgi_phys_rcp.h"
+#include "gamgi_math_vector.h"
+#include "gamgi_math_matrix.h"
+#include "gamgi_math_quaternion.h"
 #include "gamgi_io_token.h"
 
 static gamgi_enum static_class (gamgi_window *window)
@@ -34,7 +39,7 @@ GtkWidget *combo;
 const char *name;
 int row;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -359,6 +364,38 @@ else
   }
 }
 
+static void static_axis (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *label_u, *label_v, *label_w;
+GtkWidget *combo;
+int row;
+
+/*************************************************************
+ * this function updates the axis labels: plane or direction *
+ *************************************************************/
+
+label_u = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_u");
+label_v = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v");
+label_w = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_w");
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axis");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == 0)
+  {
+  gtk_label_set_text (GTK_LABEL (label_u), "H");
+  gtk_label_set_text (GTK_LABEL (label_v), "K");
+  gtk_label_set_text (GTK_LABEL (label_w), "L");
+  }
+else
+  {
+  gtk_label_set_text (GTK_LABEL (label_u), "U");
+  gtk_label_set_text (GTK_LABEL (label_v), "V");
+  gtk_label_set_text (GTK_LABEL (label_w), "W");
+  }
+}
+
 static void static_cell (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -412,6 +449,59 @@ sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_PHYS_NODE_Z);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 }
 
+static void static_start_change (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *combo;
+GtkWidget *entry;
+char token[GAMGI_ENGINE_TOKEN];
+
+/***************
+ * translation *
+ ***************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_translation_vectors");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_translation_x");
+sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_PHYS_SHIFT_X);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_translation_y");
+sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_PHYS_SHIFT_Y);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_translation_z");
+sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_PHYS_SHIFT_Z);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+/************
+ * rotation *
+ ************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_angle");
+sprintf (token, "%.*f", gamgi->gamgi->angle, 0.0);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_rotation_vectors");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axis");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 1);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_u");
+sprintf (token, "%d", GAMGI_PHYS_SHIFT_U);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v");
+sprintf (token, "%d", GAMGI_PHYS_SHIFT_V);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w");
+sprintf (token, "%d", GAMGI_PHYS_SHIFT_W);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+}
+
 static void static_start_occupancy (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -455,7 +545,7 @@ static void static_method (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *combo;
-GtkWidget *vbox_position, *vbox_occupancy, *vbox_packing;
+GtkWidget *vbox_position, *vbox_change, *vbox_occupancy, *vbox_packing;
 int row;
 
 /**********************
@@ -470,6 +560,7 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
  ************/
 
 vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
+vbox_change = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_change");
 vbox_occupancy = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_occupancy");
 vbox_packing = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_packing");
 
@@ -480,6 +571,7 @@ vbox_packing = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_packing
 if (row == 0)
   {
   gtk_widget_hide (vbox_position);
+  gtk_widget_hide (vbox_change);
   gtk_widget_hide (vbox_occupancy);
   gtk_widget_hide (vbox_packing);
   }
@@ -492,11 +584,13 @@ if (row == 0)
 if (row == 1)
   {
   gtk_widget_show (vbox_position);
+  gtk_widget_show (vbox_change);
   gtk_widget_show (vbox_occupancy);
   gtk_widget_hide (vbox_packing);
 
   static_cell (NULL, window);
   static_start_position (window);
+  static_start_change (window);
   static_start_occupancy (window);
   }
 
@@ -508,6 +602,7 @@ if (row == 1)
 if (row == 2)
   {
   gtk_widget_hide (vbox_position);
+  gtk_widget_hide (vbox_change);
   gtk_widget_hide (vbox_occupancy);
   gtk_widget_show (vbox_packing);
 
@@ -605,7 +700,9 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 static_cell (NULL, window);
 static_start_position (window);
+static_start_change (window);
 static_start_occupancy (window);
+static_start_packing (window);
 }
 
 static void static_clean (gamgi_cell *cell, gamgi_window *window)
@@ -636,7 +733,7 @@ static_start_occupancy (window);
 
 /************ internal function ************
  *                                         *
- *               STATIC_GLOBAL             *
+ *                STATIC_LIST              *
  *                                         *
  * Makes the cell entry sensitive when the *
  * local button is pressed and insensitive *
@@ -644,14 +741,17 @@ static_start_occupancy (window);
  *                                         *
  *******************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *hbox, *button;
+GtkWidget *button, *button_below, *button_above;
+GtkWidget *hbox;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_cell");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button_below = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_below");
+button_above = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_above");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -660,6 +760,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    ****************************/
 
   gtk_widget_set_sensitive (hbox, TRUE);
+  gtk_button_clicked (GTK_BUTTON (button_below));
   }
 else
   {
@@ -669,6 +770,7 @@ else
 
   static_reset (window);
   gtk_widget_set_sensitive (hbox, FALSE);
+  gtk_button_clicked (GTK_BUTTON (button_above));
   }
 }
 
@@ -687,6 +789,77 @@ else
 static_clean (cell, window);
 }
 
+static void static_rotation (gamgi_cell *cell, double angle, gamgi_enum axis,
+gamgi_enum vectors, int *uvw, double *rotation, gamgi_window *window)
+{
+double quaternion[4];
+double vector[3];
+
+/***********************
+ * get rotation matrix *
+ ***********************/
+
+if (axis == FALSE)
+  gamgi_phys_plane_vector (cell, uvw, vectors, vector);
+else
+  gamgi_phys_direction_vector (cell, uvw, vectors, vector);
+
+angle = GAMGI_MATH_DEG_RAD * angle;
+gamgi_math_quaternion_from_axis (angle, vector, quaternion);
+gamgi_math_quaternion_to_matrix (quaternion, rotation);
+}
+
+static void static_translation (gamgi_cell *cell, double *shift,
+gamgi_enum vectors, double *translation, gamgi_window *window)
+{
+double basis[9], inverse[9];
+double position[3];
+
+/***************************************************************
+ * convert coordinates in primitive vectors ([-1,+1]) or       *
+ * absolute vectors (any) to conventional vectors ([-1,+1]):   *
+ *                                                             *
+ * [conv. vectors][conv. coord] = [prim. vectors][prim. coord] *
+ * [conv. vectors][conv. coord] = [axes coord]                 *
+ *                                                             *
+ * this conversion must be done before generating positions    *
+ * with space symmetry information, as wyckoff positions       *
+ * are always given as [-1,+1] conventional coordinates        *
+ ***************************************************************/
+
+gamgi_math_vector_copy (shift, translation);
+if (vectors != GAMGI_PHYS_CONVENTIONAL)
+  {
+  gamgi_math_matrix_absolute (basis,
+  cell->a1[0], cell->a2[0], cell->a3[0],
+  cell->a1[1], cell->a2[1], cell->a3[1],
+  cell->a1[2], cell->a2[2], cell->a3[2]);
+  gamgi_math_matrix_inverse (basis, inverse);
+
+  if (vectors == GAMGI_PHYS_PRIMITIVE)
+    {
+    gamgi_math_matrix_absolute (basis,
+    cell->p1[0], cell->p2[0], cell->p3[0],
+    cell->p1[1], cell->p2[1], cell->p3[1],
+    cell->p1[2], cell->p2[2], cell->p3[2]);
+    }
+  else gamgi_math_matrix_unit (basis);
+
+  /***********************************
+   * convert to conventional vectors *
+   ***********************************/
+
+  gamgi_math_matrix_vector (basis, translation, position);
+  gamgi_math_matrix_vector (inverse, position, translation);
+
+  /*****************************************
+   * use coordinates in the range ]-1, +1[ *
+   *****************************************/
+
+  gamgi_math_vector_fmod (translation, translation);
+  }
+}
+
 static void static_ok_crystal (gamgi_cell *cell, 
 gamgi_object *object, gamgi_window *window)
 {
@@ -697,12 +870,15 @@ GtkWidget *combo;
 const char **wyckoff;
 const char *name, *rule_a, *rule_b, *rule_c;
 char token[GAMGI_ENGINE_TOKEN];
-double position[3];
-gamgi_enum vectors, cutoff;
+double position[3], shift[3];
+gamgi_enum vectors, translation_vectors, rotation_vectors;
+gamgi_enum axis, cutoff;
 gamgi_bool nodes_p, nodes_i, nodes_a, nodes_b, nodes_c, nodes_r; 
 double rotation[9];
 double translation[3];
+double angle;
 const int *driver; 
+int uvw[3];
 int site, row;
 
 /***************************************
@@ -775,10 +951,108 @@ vectors = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if ((vectors == GAMGI_PHYS_CONVENTIONAL || vectors == GAMGI_PHYS_PRIMITIVE) &&
 (abs (position[0]) >= 1.0 || abs (position[1]) >= 1.0 || abs (position[2]) >= 1.0))
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Vector Coordinates", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid position vector coordinates", window);
   return;
   }
  
+/*****************
+ * shift page *
+ *****************/
+
+/***************************************************************
+ * get translation vectors, coordinates: coordinates for       *
+ * absolute vectors must be real, coordinates for conventional *
+ * and primitive vectors must be in the range ]-1, +1[         *
+ ***************************************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_translation_vectors");
+translation_vectors = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_translation_x");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &shift[0], -DBL_MAX, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid shift coordinates", window);
+  return;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_translation_y");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &shift[1], -DBL_MAX, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid shift coordinates", window);
+  return;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_translation_z");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &shift[2], -DBL_MAX, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid shift coordinates", window);
+  return;
+  }
+
+if ((translation_vectors == GAMGI_PHYS_CONVENTIONAL ||
+translation_vectors == GAMGI_PHYS_PRIMITIVE) &&
+(abs (shift[0]) >= 1.0 || abs (shift[1]) >= 1.0 || abs (shift[2]) >= 1.0))
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid shift coordinates", window);
+  return;
+  }
+
+/*********************************************************
+ * get rotation angle, axis (direction | plane), vectors *
+ * (conventional | primitive), axis coordinates          *
+ *********************************************************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_angle");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &angle, -360.0, 360.0) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid shift angle", window);
+  return;
+  }
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axis");
+axis = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_rotation_vectors");
+rotation_vectors = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_u");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_int_scan (name, &uvw[0], -INT_MAX, INT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid shift axis", window);
+  return;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_int_scan (name, &uvw[1], -INT_MAX, INT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid shift axis", window);
+  return;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_int_scan (name, &uvw[2], -INT_MAX, INT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid shift axis", window);
+  return;
+  }
+
+if (gamgi_phys_direction_zero (uvw) == TRUE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid shift axis", window);
+  return;
+  }
+
+/******************
+ * occupancy page *
+ ******************/
+
 /************************
  * get cutoff combo box *
  ************************/
@@ -845,12 +1119,12 @@ GAMGI_IO_RULES, GAMGI_ENGINE_STRING) == FALSE)
 
 gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
 
-/*******************************************
+/**********************************************
  * get shift translation and rotation data *
- *******************************************/
+ **********************************************/
 
-gamgi_gtk_cell_shift_rotation_get (cell, rotation, window);
-gamgi_gtk_cell_shift_translation_get (cell, translation, window);
+static_rotation (cell, angle, axis, rotation_vectors, uvw, rotation, window);
+static_translation (cell, shift, translation_vectors, translation, window);
 
 /**********************************
  * link objects to cell and reset *
@@ -1031,8 +1305,10 @@ gtk_widget_size_request (GTK_WIDGET (combo_below), &size);
 if (size.width > width) width = size.width;
 if (size.height > height) height = size.height;
 
+/*
 gtk_widget_set_size_request (combo_above, width, height);
 gtk_widget_set_size_request (combo_below, width, height);
+*/
 
 /*************************************************
  * show combo box BEFORE measuring notebook size *
@@ -1050,8 +1326,10 @@ gtk_button_clicked (GTK_BUTTON (button));
  ***************************************************/
 
 notebook = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "notebook");
+gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 gtk_widget_size_request (GTK_WIDGET (notebook), &size);
 gtk_widget_set_size_request (notebook, size.width, size.height);
+gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), TRUE);
 
 /********************************************
  * hide pages AFTER measuring notebook size *
@@ -1059,12 +1337,6 @@ gtk_widget_set_size_request (notebook, size.width, size.height);
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-
-/************************
- * reset position shift *
- ************************/
-
-gamgi_gtk_cell_shift_start ();
 }
 
 static void static_press (gamgi_object *object, void *data)
@@ -1076,7 +1348,7 @@ GtkWidget *entry;
 char string[2 * GAMGI_ENGINE_TOKEN];
 const char *name;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -1107,7 +1379,7 @@ const char *name;
  * the second object, not the main object(s)   *
  ***********************************************/
  
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -1198,14 +1470,14 @@ g_signal_connect (entry, "changed", G_CALLBACK (static_cell), window);
 g_object_set_data (G_OBJECT (dialog), "entry_cell", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (button, "toggled", G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+g_signal_connect (button, "toggled", G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
@@ -1471,8 +1743,12 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  * Coordinates *
  ***************/
 
+hbox_center = gtk_hbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
 table = gtk_table_new (1, 6, FALSE);
-gtk_box_pack_start (GTK_BOX (vbox_top), table, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
 gtk_widget_show (table);
 
 entry = gtk_entry_new ();
@@ -1508,31 +1784,234 @@ label = gtk_label_new ("Z");
 gtk_table_attach (GTK_TABLE (table), label, 5, 6, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 gtk_widget_show (label);
 
-hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
+/***************
+ * Change page *
+ ***************/
+
+vbox_page = gtk_vbox_new (FALSE, 5);
+label = gtk_label_new (" Change ");
+gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
+g_object_set_data (G_OBJECT (dialog), "vbox_change", vbox_page);
+gtk_widget_show (vbox_page);
+
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
+
+vbox_top = gtk_vbox_new (FALSE, 20);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
+
+/***************
+ * Translation *
+ **************/
+
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+hbox_center = gtk_hbox_new (TRUE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-button = gtk_toggle_button_new_with_label ("Translation");
-gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (button, "clicked",
-G_CALLBACK (gamgi_gtk_cell_shift_translation), window);
-g_object_set_data (G_OBJECT (dialog), "button_translation", button);
-gtk_widget_show (button);
-
-label = gtk_label_new ("Shift");
+label = gtk_label_new ("Vectors");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
-button = gtk_toggle_button_new_with_label ("Rotation");
-gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (button, "clicked",
-G_CALLBACK (gamgi_gtk_cell_shift_rotation), window);
-g_object_set_data (G_OBJECT (dialog), "button_rotation", button);
-gtk_widget_show (button);
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "combo_translation_vectors", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Conventional", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Primitive", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Absolute", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+hbox_center = gtk_hbox_new (TRUE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
+table = gtk_table_new (1, 6, FALSE);
+gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
+gtk_widget_show (table);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_translation_x", entry);
+gtk_widget_show (entry);
+
+label = gtk_label_new ("X");
+gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_translation_y", entry);
+gtk_widget_show (entry);
+
+label = gtk_label_new ("Y");
+gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 4, 5, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_translation_z", entry);
+gtk_widget_show (entry);
+
+label = gtk_label_new ("Z");
+gtk_table_attach (GTK_TABLE (table), label, 5, 6, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+gtk_widget_show (label);
+
+/************
+ * Rotation *
+ ************/
+
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+hbox_center = gtk_hbox_new (TRUE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
+hbox_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
+
+label = gtk_label_new ("Angle");
+gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_angle", entry);
+gtk_widget_show (entry);
+
+hbox_center = gtk_hbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
+hbox_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+label = gtk_label_new ("Axis");
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
+g_signal_connect (combo, "changed", G_CALLBACK (static_axis), window);
+g_object_set_data (G_OBJECT (dialog), "combo_axis", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Plane", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Direction", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+label = gtk_label_new ("Vectors");
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "combo_rotation_vectors", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Conventional", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Primitive", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+hbox_center = gtk_hbox_new (TRUE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
+table = gtk_table_new (1, 6, FALSE);
+gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
+gtk_widget_show (table);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_u", entry);
+gtk_widget_show (entry);
+
+label = gtk_label_new ("U");
+gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_u", label);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_v", entry);
+gtk_widget_show (entry);
+
+label = gtk_label_new ("V");
+gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_v", label);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 4, 5, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_w", entry);
+gtk_widget_show (entry);
+
+label = gtk_label_new ("W");
+gtk_table_attach (GTK_TABLE (table), label, 5, 6, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_w", label);
+gtk_widget_show (label);
 
 /******************
  * Occupancy page *
@@ -1549,7 +2028,7 @@ vbox_center = gtk_vbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
 gtk_widget_show (vbox_center);
 
-vbox_top = gtk_vbox_new (FALSE, 10);
+vbox_top = gtk_vbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
@@ -1660,7 +2139,7 @@ g_object_set_data (G_OBJECT (dialog), "entry_a", entry);
 gtk_widget_show (entry);
 
 entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_ENGINE_STRING);
 g_object_set_data (G_OBJECT (dialog), "entry_b", entry);
