@@ -11,6 +11,7 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
+#include "gamgi_global.h"
 
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_find.h"
@@ -22,6 +23,7 @@
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
 
 static void static_clean (gamgi_window *window)
 {
@@ -63,15 +65,15 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-/********************* internal function ****************
- *                                                      *
- *                       STATIC_GLOBAL                  *
- *                                                      *
- * When the global button is on, disable the cell entry *
- * and reset dialog, otherwise, enable the cell entry.  *        
- ********************************************************/
+/********************* internal function ***************
+ *                                                     *
+ *                       STATIC_LIST                   *
+ *                                                     *
+ * When the List button is on, disable the cell entry  *
+ * and reset dialog, otherwise, enable the cell entry. *
+ *******************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -79,7 +81,7 @@ GtkWidget *hbox;
 GtkWidget *button;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_cell");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -100,7 +102,7 @@ else
   }
 }
 
-static void static_apply (gamgi_cell *cell, gamgi_window *window)
+static void static_apply (gamgi_cell *cell, int scope, gamgi_window *window)
 {
 gamgi_direction *direction;
 gamgi_plane *plane;
@@ -108,9 +110,6 @@ gamgi_atom *atom;
 gamgi_bond *bond;
 gamgi_object *parent;
 gamgi_dlist *dlist, *dlist_b;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-int row;
 
 /*****************************************************
  * Remove cell data according to Scope combo box:    *
@@ -121,14 +120,11 @@ int row;
  * 4) Child: Remove the child list of a given class; *
  *****************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
 /*****************************************
  * All: remove cell and all its contents *
  *****************************************/
 
-if (row == 0)
+if (scope == 0)
   {
   gamgi_engine_unlink_cell (cell);
   gamgi_engine_remove_cell (cell);
@@ -139,7 +135,7 @@ if (row == 0)
    planes and directions must be removed) and remove cell    *
  *************************************************************/
 
-if (row == 1)
+if (scope == 1)
   {
   parent = cell->object.object;
   gamgi_engine_reparent_cell (cell->cluster_start, parent);
@@ -185,7 +181,7 @@ if (row == 1)
  * Contents: remove all child objects in cell *
  **********************************************/
 
-if (row == 2)
+if (scope == 2)
   {
   dlist = cell->cluster_start;
   while (dlist != NULL)
@@ -248,7 +244,7 @@ if (row == 2)
  * Cluster: remove cluster list in cell *
  ***************************************/
 
-if (row == 3)
+if (scope == 3)
   {
   dlist = cell->cluster_start;
   while (dlist != NULL)
@@ -262,7 +258,7 @@ if (row == 3)
  * Molecule: remove molecule list in cell *
  ******************************************/
 
-if (row == 4)
+if (scope == 4)
   {
   dlist = cell->molecule_start;
   while (dlist != NULL)
@@ -276,7 +272,7 @@ if (row == 4)
  * Group: remove group list in cell *
  ************************************/
 
-if (row == 5)
+if (scope == 5)
   {
   dlist = cell->group_start;
   while (dlist != NULL)
@@ -290,7 +286,7 @@ if (row == 5)
  * Plane: remove plane list in cell *
  ************************************/
 
-if (row == 6)
+if (scope == 6)
   {
   dlist = cell->plane_start;
   while (dlist != NULL)
@@ -304,7 +300,7 @@ if (row == 6)
  * Direction: remove direction list in cell *
  ********************************************/
 
-if (row == 7)
+if (scope == 7)
   {
   dlist = cell->direction_start;
   while (dlist != NULL)
@@ -318,7 +314,7 @@ if (row == 7)
  * Atom: remove atom list in cell *
  **********************************/
 
-if (row == 8)
+if (scope == 8)
   {
   dlist = cell->atom_start;
   while (dlist != NULL)
@@ -332,7 +328,7 @@ if (row == 8)
  * Bond: remove bond list in atom list in cell *
  ***********************************************/
 
-if (row == 9)
+if (scope == 9)
   {
   dlist = cell->atom_start;
   while (dlist != NULL)
@@ -355,7 +351,7 @@ if (row == 9)
  * Orbital: remove orbital list in cell *
  ****************************************/
 
-if (row == 10)
+if (scope == 10)
   {
   dlist = cell->orbital_start;
   while (dlist != NULL)
@@ -369,7 +365,7 @@ if (row == 10)
  * Text: remove text list in cell *
  **********************************/
 
-if (row == 11)
+if (scope == 11)
   {
   dlist = cell->text_start;
   while (dlist != NULL)
@@ -381,57 +377,134 @@ if (row == 11)
 
 }
 
-static void static_ok (GtkWidget *widget, void *data)
+static void static_ok_global (int scope, gamgi_window *window)
+{
+gamgi_dlist *dlist, *cells;
+
+if (gamgi->cells == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of cell objects", window); return; }
+
+/************************************************
+ * for all windows: save layers as undo layers, *
+ * set current layer as new current object      *
+ ************************************************/
+
+gamgi_global_selection_undo ();
+gamgi_global_selection_focus ();
+
+/*********************************************************
+ * disable automatic mechanism to remove selection list, *
+ * so we can scan the list and remove it only in the end *
+ *********************************************************/
+
+cells = gamgi->cells;
+gamgi->cells = NULL;
+
+/*******************************************************
+ *  remove cell data as specified in scope combo box   *
+ *                                                     *
+ * cells are recursive objects: a cell may recursively *
+ * remove a child of the same class that appears later *
+ * in the list: listed objects that were already       *
+ * removed will have a list node pointing to NULL      *
+ *******************************************************/
+
+for (dlist =cells; dlist != NULL; dlist = dlist->next)
+    static_apply (GAMGI_CAST_CELL dlist->data, scope, window);
+
+/******************************************************
+ * remove the selection list of a class of objects    *
+ * only when objects of that class are really removed *
+ ******************************************************/
+
+gamgi->cells = cells;
+if (scope < 2)
+  gamgi_global_selection_remove (&gamgi->cells, "button_cell");
+
+/*****************************************
+ * For all windows: redraw gl_area image *
+ *****************************************/
+
+gamgi_global_selection_draw ();
+}
+
+static void static_ok_local (int scope, gamgi_window *window)
 {
-gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_cell *cell;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *button;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
+/***************
+ * Pick object *
+ ***************/
+
+cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
+"entry_cell", GAMGI_ENGINE_CELL, window);
+if (cell == NULL)
   {
-  /***************
-   * Pick method *
-   ***************/
-
-  cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
-  "entry_cell", GAMGI_ENGINE_CELL, window);
-  if (cell == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid cell object", window);
-    return;
-    }
-
-  /*************************************************
-   * Before removing the cell, check if the        *
-   * current object is affected. In this case, the *
-   * current layer becomes the new current object. *
-   *************************************************/
-
-  if (gamgi_engine_find_object (window->focus,
-  GAMGI_CAST_OBJECT cell) == TRUE)
-    gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
-
-  /***************************************
-   * Save current layer as undo buffer   *
-   * layer so it can be recovered later. *
-   ***************************************/
-
-  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
-
-  /********************************************
-   * remove cell data as chosen in scope menu *
-   ********************************************/
-
-  static_apply (cell, window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid cell object", window);
+  return;
   }
 
+/*************************************************
+ * Before removing the cell, check if the        *
+ * current object is affected. In this case, the *
+ * current layer becomes the new current object. *
+ *************************************************/
+
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT cell) == TRUE)
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ ***************************************/
+
+gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/*************************************************
+ * remove cell data as chosen in scope combo box *
+ *************************************************/
+
+static_apply (cell, scope, window);
+
 /*********************************************
  * Redraw gl_area image and reset cell entry *
  *********************************************/
 
 gtk_widget_queue_draw (window->area);
+}
+
+static void static_ok (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *button;
+GtkWidget *combo;
+int scope;
+
+/*********************************************************
+ * get dialog data common to both local and global tasks *
+ *********************************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
+scope = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+/********************************
+ * execute global or local task *
+ ********************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (scope, window);
+else
+  static_ok_local (scope, window);
+
+/***********************************************************
+ * clean dialog data common to both local and global tasks *
+ ***********************************************************/
+
 static_clean (window);
 }
 
@@ -478,7 +551,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -556,15 +629,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_cell", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
