@@ -1118,9 +1118,9 @@ vbox_dialog = gtk_vbox_new (FALSE, 5);
 gtk_container_add (GTK_CONTAINER (dialog), vbox_dialog);
 gtk_widget_show (vbox_dialog);
 
-/********************
- * Direction object *
- ********************/
+/******************
+ * Direction name *
+ ******************/
 
 hbox_center = gtk_hbox_new (TRUE, 5);
 gtk_box_pack_start (GTK_BOX (vbox_dialog), hbox_center, FALSE, FALSE, 0);
@@ -1130,7 +1130,7 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Direction");
+label = gtk_label_new ("Name");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
