@@ -25,6 +25,12 @@ static void static_method (GtkWidget *widget, void *data);
 
 static void static_reset (gamgi_window *window);
 
+static gamgi_dlist *static_ok_name (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window);
+
+static gamgi_dlist *static_ok_parent (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_enum class, gamgi_window *window);
+
 static gamgi_dlist *static_ok_scale (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window);
 
