@@ -13,8 +13,10 @@
 #include "gamgi_gtk.h"
 #include "gamgi_mesa.h"
 #include "gamgi_math.h"
+#include "gamgi_io.h"
 #include "gamgi_global.h"
 
+#include "gamgi_engine_list.h"
 #include "gamgi_engine_find.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
@@ -24,9 +26,29 @@
 #include "gamgi_math_vector.h"
 #include "gamgi_math_matrix.h"
 #include "gamgi_io_token.h"
+#include "gamgi_io_error.h"
+#include "gamgi_global_selection.h"
 
 static void static_press (gamgi_object *object, void *data);
 
+static struct {
+gamgi_bool local;
+gamgi_bool new[21];
+char name[GAMGI_ENGINE_TOKEN];
+gamgi_enum type;
+double top, near, far;
+double eye[3], center[3], up[3];
+gamgi_enum visibility_in, visibility_out;
+gamgi_enum axes;
+float red, green, blue;
+double scale; } cache;
+
+enum { STATIC_NAME = 0, STATIC_TYPE, STATIC_TOP, STATIC_NEAR,
+STATIC_FAR, STATIC_EYE_X, STATIC_EYE_Y, STATIC_EYE_Z,
+STATIC_CENTER_X, STATIC_CENTER_Y, STATIC_CENTER_Z, STATIC_UP_X,
+STATIC_UP_Y, STATIC_UP_Z, STATIC_VISIBILITY_IN, STATIC_VISIBILITY_OUT,
+STATIC_AXES, STATIC_RED, STATIC_GREEN, STATIC_BLUE, STATIC_SCALE };
+
 /******************** internal function *****************
  *                                                      *
  *                      STATIC_RESET                    *
@@ -105,442 +127,599 @@ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 2);
 
 /************ internal function *************
  *                                          *
- *               STATIC_GLOBAL              *
- *                                          *
- * Makes the layer entry sensitive when the *
- * local button is pressed and insensitive  *
- * when the global button is pressed.       *
+ *                STATIC_LIST               *
  *                                          *
  ********************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *hbox, *button;
-
-hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_layer");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+GtkWidget *label, *button;
 
+label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_layer");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
-  /*****************************
-   * Choose the Layer directly *
-   *****************************/
+  /*********************************
+   * modify a single layer directly *
+   *********************************/
 
-  gtk_widget_set_sensitive (hbox, TRUE);
+  gtk_label_set_text (GTK_LABEL (label), "Layer");
   }
 else
   {
   /*********************************************
-   * Choose the Layer List previously selected *
+   * modify multiple layers previously selected *
    *********************************************/
 
+  gtk_label_set_text (GTK_LABEL (label), "Name");
   static_reset (window);
-  gtk_widget_set_sensitive (hbox, FALSE);
   }
 }
 
+static gamgi_bool static_grab (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+GtkWidget *combo;
+const char *name;
+int row;
 
-/************ internal function **********
- *                                       *
- *               STATIC_OK               *
- *                                       *
- *  This is the function that creates a  *
- *  new layer, when the user presses Ok. *
- *                                       *
+/************************
+ * type, top, near, far *
+ ************************/
+
+cache.new[STATIC_TYPE] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_projection");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row < 2) { cache.new[STATIC_TYPE] = TRUE; cache.type = row + 1; }
+
+cache.new[STATIC_TOP] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_top");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_TOP] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.top, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid volume parameter", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_NEAR] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_near");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_NEAR] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.near, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid volume parameter", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_FAR] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_far");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_FAR] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.far, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid volume parameter", window);
+    return FALSE;
+    }
+  }
+
+/*******************
+ * eye, center, up *
+ *******************/
+
+cache.new[STATIC_EYE_X] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_eye_x");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_EYE_X] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.eye[0], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid view parameter", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_EYE_Y] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_eye_y");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_EYE_Y] = TRUE;
+  if (gamgi_io_token_double_scan (name, 
+  &cache.eye[1], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid view parameter", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_EYE_Z] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_eye_z");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_EYE_Z] = TRUE;
+  if (gamgi_io_token_double_scan (name, 
+  &cache.eye[2], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid view parameter", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_CENTER_X] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_center_x");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_CENTER_X] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.center[0], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid view parameter", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_CENTER_Y] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_center_y");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_CENTER_Y] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.center[1], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid view parameter", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_CENTER_Z] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_center_z");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_CENTER_Z] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.center[2], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid view parameter", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_UP_X] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_up_x");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_UP_X] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.up[0], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid view parameter", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_UP_Y] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_up_y");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_UP_Y] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.up[1], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid view parameter", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_UP_Z] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_up_z");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_UP_Z] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.up[2], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid view parameter", window);
+    return FALSE;
+    }
+  }
+
+/********************************
+ * visibility_in, visibility_ut *
+ ********************************/
+
+cache.new[STATIC_VISIBILITY_IN] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_in");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row < 3)
+  { cache.new[STATIC_VISIBILITY_IN] = TRUE;
+  cache.visibility_in = row + 1; }
+
+cache.new[STATIC_VISIBILITY_OUT] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_out");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row < 3)
+  { cache.new[STATIC_VISIBILITY_OUT] = TRUE;
+  cache.visibility_out = row + 1; }
+
+/*********************************
+ * axes, red, green, blue, scale *
+ *********************************/
+
+cache.new[STATIC_AXES] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row < 2)
+  {
+  cache.new[STATIC_AXES] = TRUE;
+  if (row == GAMGI_GTK_YES - 1) cache.axes = TRUE;
+  if (row == GAMGI_GTK_NO - 1) cache.axes = FALSE;
+  }
+
+cache.new[STATIC_RED] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_RED] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.red, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid layer color", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_GREEN] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_GREEN] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.green, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid layer color", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_BLUE] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_BLUE] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.blue, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid layer color", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_SCALE] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_SCALE] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid layer scale", window);
+    return FALSE;
+    }
+  }
+
+return TRUE;
+}
+
+static gamgi_bool static_apply (gamgi_layer *layer, gamgi_window *window)
+{
+gamgi_enum type;
+gamgi_enum visibility_in, visibility_out, axes;
+char name[GAMGI_ENGINE_TOKEN];
+double eye[3], center[3], up[3];
+double x[3], z[3], up_z[3];
+double top, near, far, scale;
+double length;
+float red, green, blue;
+
+/**************************
+ * import data from layer *
+ **************************/
+
+if (layer->perspective == TRUE)
+  type = GAMGI_MESA_PERSPECTIVE;
+else
+  type = GAMGI_MESA_ORTHOGRAPHIC;
+top = layer->top;
+near = layer->near;
+far = layer->far;
+
+gamgi_math_vector_copy (layer->eye, eye);
+gamgi_math_vector_copy (layer->center, center);
+gamgi_math_vector_copy (layer->up, up);
+
+visibility_in = layer->visibility_in;
+visibility_out = layer->visibility_out;
+
+axes = layer->axes;
+red = layer->color[0];
+green = layer->color[1];
+blue = layer->color[2];
+scale = layer->object.scale;
+
+/******************
+ * apply new data *
+ ******************/
+
+if (cache.new[STATIC_NAME] == TRUE) strcpy (name, cache.name);
+
+if (cache.new[STATIC_TYPE] == TRUE) type = cache.type;
+if (cache.new[STATIC_TOP] == TRUE) top = cache.top;
+if (cache.new[STATIC_NEAR] == TRUE) near = cache.near;
+if (cache.new[STATIC_FAR] == TRUE) far = cache.far;
+
+if (cache.new[STATIC_EYE_X] == TRUE) eye[0] = cache.eye[0];
+if (cache.new[STATIC_EYE_Y] == TRUE) eye[1] = cache.eye[1];
+if (cache.new[STATIC_EYE_Z] == TRUE) eye[2] = cache.eye[2];
+if (cache.new[STATIC_CENTER_X] == TRUE) center[0] = cache.center[0];
+if (cache.new[STATIC_CENTER_Y] == TRUE) center[1] = cache.center[1];
+if (cache.new[STATIC_CENTER_Z] == TRUE) center[2] = cache.center[2];
+if (cache.new[STATIC_UP_X] == TRUE) up[0] = cache.up[0];
+if (cache.new[STATIC_UP_Y] == TRUE) up[1] = cache.up[1];
+if (cache.new[STATIC_UP_Z] == TRUE) up[2] = cache.up[2];
+
+if (cache.new[STATIC_VISIBILITY_IN] == TRUE)
+  visibility_in = cache.visibility_in;
+if (cache.new[STATIC_VISIBILITY_OUT] == TRUE)
+  visibility_out = cache.visibility_out;
+
+if (cache.new[STATIC_AXES] == TRUE) axes = cache.axes;
+if (cache.new[STATIC_RED] == TRUE) red = cache.red;
+if (cache.new[STATIC_GREEN] == TRUE) green = cache.green;
+if (cache.new[STATIC_BLUE] == TRUE) blue = cache.blue;
+if (cache.new[STATIC_SCALE] == TRUE) scale = cache.scale;
+
+/****************************
+ * check data compatibility *
+ ****************************/
+
+if (far < near + GAMGI_MATH_TOLERANCE_LENGTH)
+  {
+  /*********************************
+   * far must be farther than near *
+   *********************************/
+
+  if (cache.local == TRUE) gamgi_gtk_dialog_message_create
+  ("Error", "Invalid view parameters", window);
+  return FALSE;
+  }
+
+gamgi_math_vector_sub (eye, center, z);
+length = gamgi_math_vector_length (z);
+if (length < near || length > far)
+  {
+  /*********************************************************
+   * the distance eye-center must be in the near-far range *
+   *********************************************************/
+
+  if (cache.local == TRUE) gamgi_gtk_dialog_message_create
+  ("Error", "Invalid view parameters", window);
+  return FALSE;
+  }
+gamgi_math_vector_normal (z);
+
+length = gamgi_math_vector_dot (up, z);
+gamgi_math_vector_scale (z, up_z, length);
+gamgi_math_vector_sub (up, up_z, up);
+length = gamgi_math_vector_length (up);
+if (length < GAMGI_MATH_TOLERANCE_LENGTH)
+  {
+  /********************************************************
+   * the up component normal to eye-center cannot be zero *
+   ********************************************************/
+  
+  if (cache.local == TRUE) gamgi_gtk_dialog_message_create
+  ("Error", "Invalid view parameters", window);
+  return FALSE;
+  }
+gamgi_math_vector_normal (up);
+
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ * *************************************/
+
+if (cache.local == TRUE)
+  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/************************
+ * export data to layer *
+ ************************/
+
+strcpy (layer->object.name, name);
+
+if (type == GAMGI_MESA_PERSPECTIVE)
+  layer->perspective = TRUE;
+else
+  layer->perspective = FALSE;
+layer->top = top;
+layer->near = near;
+layer->far = far;
+
+gamgi_math_vector_copy (eye, layer->eye);
+gamgi_math_vector_copy (center, layer->center);
+gamgi_math_vector_copy (up, layer->up);
+
+layer->visibility_in = visibility_in;
+layer->visibility_out = visibility_out;
+
+layer->axes = axes;
+layer->color[0] = red;
+layer->color[1] = green;
+layer->color[2] = blue;
+layer->object.scale = scale;
+
+/************************
+ * set referential axes *
+ ************************/
+
+gamgi_math_vector_cross (up, z, x);
+gamgi_math_matrix_absolute (layer->referential,
+x[0], layer->up[0], z[0], x[1], layer->up[1], z[1], x[2], layer->up[2], z[2]);
+
+return TRUE;
+}
+
+static void static_ok_global (gamgi_window *window)
+{
+gamgi_dlist *dlist;
+gamgi_slist *start;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+const char *name;
+
+cache.local = FALSE;
+
+if (gamgi->layers == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of layer objects", window); return; }
+
+/****************************
+ * Pick name (possibly new) *
+ ****************************/
+
+cache.new[STATIC_NAME] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_NAME] = TRUE;
+  if (gamgi_io_token_alpha_scan (name,
+  cache.name, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid layer identity", window);
+    return;
+    }
+  }
+
+if (static_grab (window) == FALSE) return;
+
+/*************************************************
+ * For all windows: save layers as undo layers   *
+ *                                               *
+ * Modify listed objects and show error message  *
+ * with objects that could not be modified       *
+ *                                               *
+ * For all windows: set current layer as new     *
+ * current object,layer and redraw gl_area image *
+ *************************************************/
+
+gamgi_global_selection_undo ();
+
+start = NULL;
+for (dlist = gamgi->layers; dlist != NULL; dlist = dlist->next)
+  if (static_apply (GAMGI_CAST_LAYER dlist->data, window) == FALSE)
+    {
+    start = gamgi_engine_slist_add_start (start);
+    start->data = dlist->data;
+    }
+gamgi_io_error_list (start, window);
+
+gamgi_global_selection_focus ();
+gamgi_global_selection_layer ();
+gamgi_global_selection_draw ();
+
+/****************
+ * reset dialog *
+ ****************/
+
+static_reset (window);
+}
+
+static void static_ok_local (gamgi_window *window)
+{
+gamgi_layer *layer;
+GtkWidget *dialog = window->dialog0;
+
+cache.local = TRUE;
+
+/*******************************************
+ * Pick object and get name (possibly new) *
+ *******************************************/
+
+cache.new[STATIC_NAME] = TRUE;
+layer = GAMGI_CAST_LAYER gamgi_gtk_object_number (dialog,
+"entry_layer", GAMGI_ENGINE_LAYER, window, cache.name);
+if (layer == NULL)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid layer identity", window);
+  return;
+  }
+
+/*********************************************
+ * collect data from dialog and modify layer *
+ *********************************************/
+
+if (static_grab (window) == FALSE) return;
+if (static_apply (layer, window) == FALSE) return;
+
+/**********************************************************************
+ * current object,layer are affected, so change them to current layer *
+ **********************************************************************/
+
+gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+gamgi_gtk_object_layer_local (window->layer, window);
+
+/*****************************************
+ * redraw gl_area image and reset dialog *
  *****************************************/
 
+gtk_widget_queue_draw (window->area);
+static_reset (window);
+}
+
 static void static_ok (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
-gamgi_layer *layer;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-GtkWidget *button;
-GtkEntry *entry;
-const char *name;
-char token[GAMGI_ENGINE_TOKEN];
-double eye[3], center[3], up[3];
-double x[3], z[3], up_z[3];
-double top, near, far;
-double length;
-double scale;
-float red, green, blue;
-int row;
+GtkWidget* button;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
-  {
-  /****************
-   * Local method *
-   ****************/
+/*********************************************
+ * modify data: execute global or local task *
+ *********************************************/
 
-  /**************************************
-   * Get name (possibly new) and number *
-   **************************************/
-
-  layer = GAMGI_CAST_LAYER gamgi_gtk_object_number (dialog,
-  "entry_layer", GAMGI_ENGINE_LAYER, window, token);
-  if (layer == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Layer Object", window);
-    return;
-    }
-
-  /**************************
-   * get initial parameters *
-   **************************/
-
-  top = layer->top;
-  near = layer->near;
-  far = layer->far;
-  
-  gamgi_math_vector_copy (layer->eye, eye);
-  gamgi_math_vector_copy (layer->center, center);
-  gamgi_math_vector_copy (layer->up, up);
-
-  red = layer->color[0];
-  green = layer->color[1];
-  blue = layer->color[2];
-
-  scale = layer->object.scale;
-
-  /************************************
-   * get projection volume parameters *
-   ************************************/
-
-  /*******
-   * top *
-   *******/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_top");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &top, 
-  GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Volume Parameter", window);
-    return;
-    }
-
-  /********
-   * near *
-   ********/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_near");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &near, 
-  GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Volume Parameter", window);
-    return;
-    }
-
-  /*******
-   * far *
-   *******/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_far");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &far, 
-  near + GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Volume Parameter", window);
-    return;
-    }
-
-  /***********************
-   * get view parameters *
-   ***********************/
-
-  /*********
-   * eye_x *
-   *********/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_eye_x");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &eye[0], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameter", window);
-    return;
-    }
-
-  /*********
-   * eye_y *
-   *********/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_eye_y");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &eye[1], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameter", window);
-    return;
-    }
-
-  /*********
-   * eye_z *
-   *********/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_eye_z");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &eye[2], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameter", window);
-    return;
-    }
-
-  /************
-   * center_x *
-   ************/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_center_x");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &center[0], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameter", window);
-    return;
-    }
-
-  /************
-   * center_y *
-   ************/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_center_y");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &center[1], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameter", window);
-    return;
-    }
-
-  /************
-   * center_z *
-   ************/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_center_z");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &center[2], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameter", window);
-    return;
-    }
-
-  /********
-   * up_x *
-   ********/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_up_x");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &up[0], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameter", window);
-    return;
-    }
-
-  /********
-   * up_y *
-   ********/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_up_y");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &up[1], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameter", window);
-    return;
-    }
-
-  /********
-   * up_z *
-   ********/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_up_z");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &up[2], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameter", window);
-    return;
-    }
- 
-  /************************************************************
-   * check view parameters:                                   *
-   * 1) the distance eye-center must be in the near-far range *
-   * 2) the up component normal to eye-center cannot be zero  *
-   ************************************************************/
-
-  gamgi_math_vector_sub (eye, center, z);
-  length = gamgi_math_vector_length (z);
-  if (length < near || length > far)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameters", window);
-    return;
-    }
-  gamgi_math_vector_normal (z);
-
-  length = gamgi_math_vector_dot (up, z);
-  gamgi_math_vector_scale (z, up_z, length);
-  gamgi_math_vector_sub (up, up_z, up);
-  length = gamgi_math_vector_length (up);
-  if (length < GAMGI_MATH_TOLERANCE_LENGTH)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid View Parameters", window);
-    return;
-    }
-  gamgi_math_vector_normal (up);
-
-  /************************
-   * Get background color *
-   ************************/
-
-  /*******
-   * red *
-   *******/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_red");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_float_scan (name, &red, 0.0, 1.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Color Data", window);
-    return;
-    }
-
-  /*********
-   * green *
-   *********/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_green");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_float_scan (name, &green, 0.0, 1.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Color Data", window);
-    return;
-    }
-
-  /********
-   * blue *
-   ********/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_float_scan (name, &blue, 0.0, 1.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Color Data", window);
-    return;
-    }
-
-  /*************
-   * get scale *
-   *************/
-
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
-  &scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
-    return;
-    }
-
-  /******************************************
-   * input data is ok: no errors were found *
-   ******************************************/
-
-  /************************************
-   * save current layer as undo layer *
-   ************************************/
-
-  gamgi_gtk_history_update (layer, layer->undo, GAMGI_ENGINE_UNDO);
-
-  /**************************************
-   * set layer with modified parameters *
-   **************************************/
-
-  strcpy (layer->object.name, token);
-
-  layer->top = top;
-  layer->near = near;
-  layer->far = far;
-
-  gamgi_math_vector_copy (eye, layer->eye);
-  gamgi_math_vector_copy (center, layer->center);
-  gamgi_math_vector_copy (up, layer->up);
-
-  layer->color[0] = red;
-  layer->color[1] = green;
-  layer->color[2] = blue;
-
-  layer->object.scale = scale;
-
-  /************************
-   * set referential axes *
-   ************************/
-
-  gamgi_math_vector_cross (up, z, x);
-  gamgi_math_matrix_absolute (layer->referential,
-  x[0], layer->up[0], z[0], x[1], layer->up[1], z[1], x[2], layer->up[2], z[2]);
-
-  /************************
-   * get menu: projection *
-   ************************/
-
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_projection");
-  row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-  if (row == GAMGI_MESA_PERSPECTIVE - 1) layer->perspective = TRUE;
-  if (row == GAMGI_MESA_ORTHOGRAPHIC - 1) layer->perspective = FALSE;
-
-  /**********************************
-   * get menu: visibility to inside *
-   **********************************/
-
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_in");
-  row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-  if (row == GAMGI_GTK_ALL - 1) layer->visibility_in = GAMGI_GTK_ALL;
-  if (row == GAMGI_GTK_PARTIAL - 1) layer->visibility_in = GAMGI_GTK_PARTIAL;
-  if (row == GAMGI_GTK_NONE - 1) layer->visibility_in = GAMGI_GTK_NONE;
-
-  /***********************************
-   * get menu: visibility to outside *
-   ***********************************/
-
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_out");
-  row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-  if (row == GAMGI_GTK_ALL - 1) layer->visibility_out = GAMGI_GTK_ALL;
-  if (row == GAMGI_GTK_PARTIAL - 1) layer->visibility_out = GAMGI_GTK_PARTIAL;
-  if (row == GAMGI_GTK_NONE - 1) layer->visibility_out = GAMGI_GTK_NONE;
-
-  /******************
-   * get combo axes *
-   ******************/
-
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-  row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-  if (row == GAMGI_GTK_YES - 1) layer->axes = TRUE;
-  if (row == GAMGI_GTK_NO - 1) layer->axes = FALSE;
-  }
-
-/***********************************************************
- * Update statusbar, redraw gl_area image and reset dialog *
- ***********************************************************/
-
-gamgi_gtk_statusbar_focus_modify (window);
-gamgi_gtk_statusbar_layer_modify (window);
-
-gtk_widget_queue_draw (window->area);
-static_reset (window);
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (window);
+else
+  static_ok_local (window);
 }
 
 static void static_init (gamgi_window *window)
@@ -705,7 +884,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -771,11 +950,11 @@ gtk_widget_show (hbox_left);
 
 hbox_left_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "hbox_layer", hbox_left_left);
 gtk_widget_show (hbox_left_left);
 
 label = gtk_label_new ("Layer");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "label_layer", label);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
@@ -785,15 +964,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_layer", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
