@@ -27,7 +27,7 @@ GtkWidget *entry;
 GtkWidget *button;
 const char *name;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_light");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -67,7 +67,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 /**************** internal function ************
  *                                             *
- *                  STATIC_GLOBAL              *
+ *                  STATIC_LIST                *
  *                                             *
  * Makes the light entry sensitive when the    *
  * local button is pressed and insensitive     *
@@ -75,14 +75,15 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
  *                                             *
  ***********************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *hbox, *button;
+GtkWidget *button;
+GtkWidget *hbox;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_light");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -163,7 +164,7 @@ GtkWidget *entry;
 char string[2 * GAMGI_ENGINE_TOKEN];
 const char *name;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_light");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -194,7 +195,7 @@ const char *name;
  * the second object, not the main object(s)   *
  ***********************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_light");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -282,14 +283,14 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_light", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (button, "toggled", G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+g_signal_connect (button, "toggled", G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
