@@ -401,7 +401,7 @@ if (row_autonomy != GAMGI_GTK_ALL - 1 && row_autonomy != GAMGI_GTK_PARTIAL - 1)
   }
 else
   {
-  if (GTK_WIDGET_VISIBLE (vbox) == FALSE)
+  if (gtk_widget_get_visible (vbox) == FALSE)
     {
     static_start_position (window);
 
@@ -600,14 +600,14 @@ cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
 "entry_cell", GAMGI_ENGINE_CELL, window);
 if (cell != NULL && cell->type == GAMGI_PHYS_PROJECTION)
   {
-  if (GTK_WIDGET_VISIBLE (vbox_projection) == FALSE)
+  if (gtk_widget_get_visible (vbox_projection) == FALSE)
     static_start_projection (window);
   gtk_widget_hide (vbox_polygon);
   gtk_widget_show (vbox_projection);
   }
 else
   {
-  if (GTK_WIDGET_VISIBLE (vbox_polygon) == FALSE)
+  if (gtk_widget_get_visible (vbox_polygon) == FALSE)
     static_start_polygon (window);
   gtk_widget_hide (vbox_projection);
   gtk_widget_show (vbox_polygon);
@@ -1639,7 +1639,7 @@ if (class == GAMGI_ENGINE_PLANE)
       static_autonomy (NULL, window);
 
       entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
-      if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+      if (gtk_widget_is_sensitive (entry) == TRUE)
         {
         sprintf (string, "%f", plane->thickness);
         gtk_entry_set_text (GTK_ENTRY (entry), string);
@@ -1758,7 +1758,7 @@ if (class == GAMGI_ENGINE_PLANE)
   gtk_entry_set_text (GTK_ENTRY (entry), string);
 
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-  if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+  if (gtk_widget_is_sensitive (entry) == TRUE)
     {
     sprintf (string, "%.*f", GAMGI_MATH_DECIMAL_SCALE, plane->object.scale);
     gtk_entry_set_text (GTK_ENTRY (entry), string);
