@@ -29,7 +29,7 @@ GtkWidget *combo;
 const char *name;
 int row;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_text");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -151,7 +151,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 /************* internal function ***********
  *                                         *
- *               STATIC_GLOBAL             *
+ *                STATIC_LIST              *
  *                                         *
  * Makes the text entry sensitive when     *
  * the global button is up and insensitive *
@@ -159,14 +159,17 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
  *                                         *
  *******************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *hbox, *button;
+GtkWidget *button, *button_below, *button_above;
+GtkWidget *hbox;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_text");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button_below = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_below");
+button_above = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_above");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -175,6 +178,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    ****************************/
 
   gtk_widget_set_sensitive (hbox, TRUE);
+  gtk_button_clicked (GTK_BUTTON (button_below));
   }
 else
   {
@@ -184,6 +188,7 @@ else
 
   static_reset (window);
   gtk_widget_set_sensitive (hbox, FALSE);
+  gtk_button_clicked (GTK_BUTTON (button_above));
   }
 }
 
@@ -294,7 +299,7 @@ GtkWidget *entry;
 char string[2 * GAMGI_ENGINE_TOKEN];
 const char *name;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_text");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -325,7 +330,7 @@ const char *name;
  * the second object, not the main object(s)   *
  ***********************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_text");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -413,14 +418,14 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_text", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (button, "toggled", G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+g_signal_connect (button, "toggled", G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
