@@ -21,7 +21,7 @@ static void static_reset (gamgi_window *window);
 
 static void static_clean (gamgi_window *window);
 
-static void static_global (GtkWidget *widget, void *data);
+static void static_list (GtkWidget *widget, void *data);
 
 static void static_object (gamgi_text *text,
 gamgi_object *object, gamgi_window *window);
