@@ -39,18 +39,21 @@
 #include "gamgi_global_selection.h"
 
 static struct {
+gamgi_bool local;
 gamgi_bool new[14];
-
 char name[GAMGI_ENGINE_TOKEN];
+char *contents;
 gamgi_enum style, font;
 gamgi_bool translation_absolute, rotation_absolute;
 double translation[3], rotation[3];
-
-char *contents;
-
 float red, green, blue;
 double scale; } cache;
 
+enum { STATIC_NAME = 0, STATIC_CONTENTS,
+STATIC_TRANSLATION_X, STATIC_TRANSLATION_Y, STATIC_TRANSLATION_Z,
+STATIC_ROTATION_E1, STATIC_ROTATION_E2, STATIC_ROTATION_E3, STATIC_STYLE,
+STATIC_FONT, STATIC_RED, STATIC_GREEN, STATIC_BLUE, STATIC_SCALE };
+
 static gamgi_enum static_font (gamgi_enum style, int offset)
 {
 /************************************************************
@@ -354,7 +357,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 else
   {
   /*********************************************
-   * modify multiple atoms previously selected *
+   * modify multiple texts previously selected *
    *********************************************/
 
   gtk_label_set_text (GTK_LABEL (label), "Name");
@@ -374,35 +377,35 @@ GtkTextBuffer *buffer;
 GtkTextIter start;
 GtkTextIter end;
 const char *name;
-int row, i = 0;
+int row;
 
 /*******************************************
  * style, font: when style is unknown,     *
  * the new font depends of the text object *
  *******************************************/
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_STYLE] = FALSE;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (row < 2) { cache.new[i] = TRUE; cache.style = row + 1; }
+if (row < 2) { cache.new[STATIC_STYLE] = TRUE; cache.style = row + 1; }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_FONT] = FALSE;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_font");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (cache.style == GAMGI_MESA_WIRED)
   {
   if (row < GAMGI_IO_FONTS_WIRED)
-    { cache.new[i] = TRUE; cache.font = 1 + row; }
+    { cache.new[STATIC_FONT] = TRUE; cache.font = 1 + row; }
   }
 else if (cache.style == GAMGI_MESA_SOLID)
   {
   if (row < GAMGI_IO_FONTS_SOLID)
-    { cache.new[i] = TRUE; cache.font = 1 + row + GAMGI_IO_FONTS_WIRED; }
+    { cache.new[STATIC_FONT] = TRUE; cache.font = 1 + row + GAMGI_IO_FONTS_WIRED; }
   }
 else
   {
   if (row < GAMGI_IO_FONTS_TOTAL)
-    { cache.new[i] = TRUE; cache.font = row; }
+    { cache.new[STATIC_FONT] = TRUE; cache.font = row; }
   }
 
 /******************************
@@ -415,44 +418,44 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
 else
   cache.translation_absolute = FALSE;
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_TRANSLATION_X] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_TRANSLATION_X] = TRUE;
   if (gamgi_io_token_double_scan (name,
   &cache.translation[0], -DBL_MAX, DBL_MAX) == FALSE)
     {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid position", window);
+    gamgi_gtk_dialog_message_create ("Error", "Invalid text translation", window);
     return FALSE;
     }
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_TRANSLATION_Y] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_TRANSLATION_Y] = TRUE;
   if (gamgi_io_token_double_scan (name,
   &cache.translation[1], -DBL_MAX, DBL_MAX) == FALSE)
     {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid position", window);
+    gamgi_gtk_dialog_message_create ("Error", "Invalid text translation", window);
     return FALSE;
     }
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_TRANSLATION_Z] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_TRANSLATION_Z] = TRUE;
   if (gamgi_io_token_double_scan (name,
   &cache.translation[2], -DBL_MAX, DBL_MAX) == FALSE)
     {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid position", window);
+    gamgi_gtk_dialog_message_create ("Error", "Invalid text translation", window);
     return FALSE;
     }
   }
@@ -467,65 +470,44 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
 else
   cache.rotation_absolute = FALSE;
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_ROTATION_E1] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_ROTATION_E1] = TRUE;
   if (gamgi_io_token_double_scan (name,
   &cache.rotation[0], 0.0, 180.0) == FALSE)
     {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
+    gamgi_gtk_dialog_message_create ("Error", "Invalid text rotation", window);
     return FALSE;
     }
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_ROTATION_E2] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_ROTATION_E2] = TRUE;
   if (gamgi_io_token_double_scan (name,
   &cache.rotation[1], 0.0, 360.0) == FALSE)
     {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
+    gamgi_gtk_dialog_message_create ("Error", "Invalid text rotation", window);
     return FALSE;
     }
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_ROTATION_E3] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_ROTATION_E3] = TRUE;
   if (gamgi_io_token_double_scan (name,
   &cache.rotation[2], 0.0, 360.0) == FALSE)
     {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
-    return FALSE;
-    }
-  }
-
-/************
- * contents *
- ************/
-
-cache.new[++i] = FALSE;
-text_view = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "text_contents");
-buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
-gtk_text_buffer_get_start_iter (buffer, &start);
-gtk_text_buffer_get_end_iter (buffer, &end);
-cache.contents = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
-if (gamgi_io_token_check (cache.contents) == TRUE)
-  {
-  cache.new[i] = TRUE;
-  if (gamgi_io_token_alpha_check (cache.contents,
-  GAMGI_IO_FONT_ASCII, GAMGI_ENGINE_LINE) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid text contents", window);
+    gamgi_gtk_dialog_message_create ("Error", "Invalid text rotation", window);
     return FALSE;
     }
   }
@@ -534,12 +516,12 @@ if (gamgi_io_token_check (cache.contents) == TRUE)
  * red, green, blue, scale *
  ***************************/
   
-cache.new[++i] = FALSE;
+cache.new[STATIC_RED] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_RED] = TRUE;
   if (gamgi_io_token_float_scan (name,
   &cache.red, 0.0, 1.0) == FALSE)
     {
@@ -548,12 +530,12 @@ if (gamgi_io_token_check (name) == TRUE)
     }
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_GREEN] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_GREEN] = TRUE;
   if (gamgi_io_token_float_scan (name,
   &cache.green, 0.0, 1.0) == FALSE)
     {
@@ -562,12 +544,12 @@ if (gamgi_io_token_check (name) == TRUE)
     }
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_BLUE] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_BLUE] = TRUE;
   if (gamgi_io_token_float_scan (name,
   &cache.blue, 0.0, 1.0) == FALSE)
     {
@@ -576,12 +558,12 @@ if (gamgi_io_token_check (name) == TRUE)
     }
   }
 
-cache.new[++i] = FALSE;
+cache.new[STATIC_SCALE] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[i] = TRUE;
+  cache.new[STATIC_SCALE] = TRUE;
   if (gamgi_io_token_double_scan (name,
   &cache.scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
     {
@@ -590,11 +572,31 @@ if (gamgi_io_token_check (name) == TRUE)
     }
   }
 
+/************
+ * contents *
+ ************/
+
+cache.new[STATIC_CONTENTS] = FALSE;
+text_view = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "text_contents");
+buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
+gtk_text_buffer_get_start_iter (buffer, &start);
+gtk_text_buffer_get_end_iter (buffer, &end);
+cache.contents = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
+if (gamgi_io_token_check (cache.contents) == TRUE)
+  {
+  cache.new[STATIC_CONTENTS] = TRUE;
+  if (gamgi_io_token_alpha_check (cache.contents,
+  GAMGI_IO_FONT_ASCII, GAMGI_ENGINE_LINE) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid text contents", window);
+    return FALSE;
+    }
+  }
+
 return TRUE;
 }
 
-static gamgi_bool static_apply (gamgi_text *text, gamgi_bool local,
-gamgi_window *window)
+static gamgi_bool static_apply (gamgi_text *text, gamgi_window *window)
 {
 char name[GAMGI_ENGINE_TOKEN];
 char line[GAMGI_ENGINE_LINE];
@@ -602,9 +604,8 @@ double origin[3], origin_old[3];
 double euler[3], euler_old[3];
 double zero[3], center[3];
 double scale;
-gamgi_enum style, font;
 float red, green, blue;
-int i = 0;
+gamgi_enum style, font, cache_font;
 
 /*************************
  * import data from text *
@@ -631,60 +632,73 @@ green = text->green;
 blue = text->blue;
 scale = text->object.scale;
 
-/******************
- * apply new data *
- ******************/
+/*******************************************
+ * apply new data: when style is unknown,  *
+ * the new font depends of the text object *
+ *******************************************/
 
-if (cache.new[i++] == TRUE)
-  strcpy (name, cache.name);
+if (cache.new[STATIC_NAME] == TRUE) strcpy (name, cache.name);
 
-/******************************************************************
- * when style is unknown, the new font depends of the text object *
- ******************************************************************/
+if (cache.new[STATIC_STYLE] == TRUE) style = cache.style;
+if (cache.new[STATIC_STYLE] == FALSE && cache.new[STATIC_FONT] == TRUE)
+  cache_font = static_font (text->style, cache.font);
+else cache_font = cache.font;
+if (cache.new[STATIC_FONT] == TRUE) font = cache_font;
 
-if (cache.new[1] == FALSE && cache.new[2] == TRUE)
-  { cache.font = static_font (text->style, cache.font); }
+if (cache.new[STATIC_TRANSLATION_X] == TRUE) origin[0] = cache.translation[0];
+if (cache.new[STATIC_TRANSLATION_Y] == TRUE) origin[1] = cache.translation[1];
+if (cache.new[STATIC_TRANSLATION_Z] == TRUE) origin[2] = cache.translation[2];
+if (cache.new[STATIC_ROTATION_E1] == TRUE) euler[0] = cache.rotation[0];
+if (cache.new[STATIC_ROTATION_E2] == TRUE) euler[1] = cache.rotation[1];
+if (cache.new[STATIC_ROTATION_E3] == TRUE) euler[2] = cache.rotation[2];
 
-if (cache.new[i++] == TRUE) style = cache.style;
-if (cache.new[i++] == TRUE) font = cache.font;
+if (cache.translation_absolute == FALSE)
+  gamgi_math_vector_add (origin, origin_old, origin);
+if (cache.rotation_absolute == FALSE)
+  gamgi_math_vector_add (euler, euler_old, euler);
+
+if (cache.new[STATIC_RED] == TRUE) red = cache.red;
+if (cache.new[STATIC_GREEN] == TRUE) green = cache.green;
+if (cache.new[STATIC_BLUE] == TRUE) blue = cache.blue;
+if (cache.new[STATIC_SCALE] == TRUE) scale = cache.scale;
+
+/****************************
+ * check data compatibility *
+ ****************************/
 
 if (style == GAMGI_MESA_WIRED && font > GAMGI_IO_FONTS_WIRED)
   {
-  if (local == TRUE)
+  /*******************************
+   * wired style with solid font *
+   *******************************/
+
+  if (cache.local == TRUE)
     gamgi_gtk_dialog_message_create ("Error", "Invalid font data", window);
-  return TRUE;
+  return FALSE;
   }
+
 if (style == GAMGI_MESA_SOLID && font <= GAMGI_IO_FONTS_WIRED)
   {
-  if (local == TRUE)
+  /*******************************
+   * solid style with wired font *
+   *******************************/
+
+  if (cache.local == TRUE)
     gamgi_gtk_dialog_message_create ("Error", "Invalid font data", window);
-  return TRUE;
+  return FALSE;
   }
 
-if (cache.new[i++] == TRUE)
-  origin[0] = cache.translation[0];
-if (cache.new[i++] == TRUE)
-  origin[1] = cache.translation[1];
-if (cache.new[i++] == TRUE)
-  origin[2] = cache.translation[2];
-
-if (cache.new[i++] == TRUE)
-  euler[0] = cache.rotation[0];
-if (cache.new[i++] == TRUE)
-  euler[1] = cache.rotation[1];
-if (cache.new[i++] == TRUE)
-  euler[2] = cache.rotation[2];
-
-/******************
- * get new center *
- ******************/
-
-if (cache.new[i++] == TRUE)
+if (cache.new[STATIC_CONTENTS] == TRUE)
   {
   if (gamgi_mesa_text_center (font,
   cache.contents, strlen (cache.contents), center, line) == FALSE)
     {
-    gamgi_gtk_dialog_message_create ("Error", line, window);
+    /***********************************
+     * new center cannot be calculated *
+     ***********************************/
+
+    if (cache.local == TRUE)
+      gamgi_gtk_dialog_message_create ("Error", line, window);
     return FALSE;
     }
   }
@@ -693,26 +707,22 @@ else
   if (gamgi_mesa_text_center (font,
   text->string, text->length, center, line) == FALSE)
     {
-    gamgi_gtk_dialog_message_create ("Error", line, window);
+    /***********************************
+     * old center cannot be calculated *
+     ***********************************/
+
+    if (cache.local == TRUE)
+      gamgi_gtk_dialog_message_create ("Error", line, window);
     return FALSE;
     }
   }
 
-if (cache.new[i++] == TRUE)
-  red = cache.red;
-if (cache.new[i++] == TRUE)
-  green = cache.green;
-if (cache.new[i++] == TRUE)
-  blue = cache.blue;
-if (cache.new[i++] == TRUE)
-  scale = cache.scale;
-
 /***************************************
  * Save current layer as undo buffer   *
  * layer so it can be recovered later. *
  ***************************************/
 
-if (local == TRUE)
+if (cache.local == TRUE)
   gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
 
 /***********************************************
@@ -727,7 +737,7 @@ gamgi_math_vector_zero (zero);
 gamgi_math_position_text_rotation_set (text, zero);
 gamgi_math_position_text_translation_set (text, zero);
 
-if (cache.new[9] == TRUE)
+if (cache.new[STATIC_CONTENTS] == TRUE)
   {
   gamgi_mesa_text_font_decrease (text);
   gamgi_mesa_text_remove (text);
@@ -741,14 +751,9 @@ else if (font != text->font)
   text->font = font;
   gamgi_mesa_text_font_increase (text, NULL);
   }
+
 gamgi_math_vector_copy (center, text->center);
-
-if (cache.rotation_absolute == FALSE)
-  gamgi_math_vector_add (euler, euler_old, euler);
 gamgi_math_position_text_rotation_set (text, euler);
-
-if (cache.translation_absolute == FALSE)
-  gamgi_math_vector_add (origin, origin_old, origin);
 gamgi_math_position_text_translation_set (text, origin);
 
 text->red = red;
@@ -761,14 +766,13 @@ return TRUE;
 
 static void static_ok_global (gamgi_window *window)
 {
-gamgi_object *object;
 gamgi_dlist *dlist;
-gamgi_slist *slist, *start;
+gamgi_slist *start;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 const char *name;
-char line[GAMGI_ENGINE_LINE];
-char string[GAMGI_ENGINE_STRING];
+
+cache.local = FALSE;
 
 if (gamgi->texts == NULL)
   { gamgi_gtk_dialog_message_create ("Error",
@@ -778,12 +782,12 @@ if (gamgi->texts == NULL)
  * Pick name (possibly new) *
  ****************************/
 
-cache.new[0] = FALSE;
+cache.new[STATIC_NAME] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_text");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
-  cache.new[0] = TRUE;
+  cache.new[STATIC_NAME] = TRUE;
   if (gamgi_io_token_alpha_scan (name,
   cache.name, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
     {
@@ -795,51 +799,26 @@ if (gamgi_io_token_check (name) == TRUE)
 if (static_grab (window) == FALSE) return;
 
 /************************************************
- * for all windows: save layers as undo layers, *
- * set current layer as new current object      *
+ * For all windows: save layers as undo layers  *
+ * and set current layer as new current object  *
+ *                                              *
+ * Modify listed objects and show error message *
+ * with objects that could not be modified      *
+ *                                              *
+ * For all windows: redraw gl_area image        *
  ************************************************/
 
 gamgi_global_selection_undo ();
 gamgi_global_selection_focus ();
 
-/*******************************************
- * modify text data as specified in dialog *
- *******************************************/
-
 start = NULL;
 for (dlist = gamgi->texts; dlist != NULL; dlist = dlist->next)
-  if (static_apply (GAMGI_CAST_TEXT dlist->data, FALSE, window) == FALSE)
+  if (static_apply (GAMGI_CAST_TEXT dlist->data, window) == FALSE)
     {
     start = gamgi_engine_slist_add_start (start);
     start->data = dlist->data;
     }
-
-if (start != NULL)
-  {
-  printf ("error\n");
-  fflush (stdout);
-
-  sprintf (line, "The following objects could not be modified:\n");
-
-  start = gamgi_engine_slist_invert (start);
-  for (slist = start; slist != NULL; slist = slist->next)
-    {
-    if (slist != start) strcat (line, ", ");
-
-    if (strlen (line) > GAMGI_ENGINE_LINE - GAMGI_ENGINE_STRING)
-      { strcat (line, "..."); break; }
-
-    object = GAMGI_CAST_OBJECT slist->data;
-    sprintf (string, "%s %d", object->name, object->number);
-    strcat (line, string);
-    }
-  gamgi_gtk_dialog_message_create ("Error", line, window);
-  gamgi_engine_slist_remove_all (start);
-  }
-
-/*****************************************
- * For all windows: redraw gl_area image *
- *****************************************/
+gamgi_io_error_list (start, window);
 
 gamgi_global_selection_draw ();
 
@@ -854,12 +833,17 @@ static void static_ok_local (gamgi_window *window)
 {
 gamgi_text *text;
 GtkWidget *dialog = window->dialog0;
+gamgi_bool focus;
 
-/*******************************************
- * Pick object and get name (possibly new) *
- *******************************************/
+cache.local = TRUE;
 
-cache.new[0] = TRUE;
+/*****************************************
+ * pick text and get name (possibly new) *
+ *                                       *
+ * check if focus object belongs to text *
+ *****************************************/
+
+cache.new[STATIC_NAME] = TRUE;
 text = GAMGI_CAST_TEXT gamgi_gtk_object_number (dialog,
 "entry_text", GAMGI_ENGINE_TEXT, window, cache.name);
 if (text == NULL)
@@ -868,24 +852,29 @@ if (text == NULL)
   return;
   }
 
+focus = FALSE;
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT text) == TRUE) focus = TRUE;
+
+/********************************************
+ * collect data from dialog and modify text *
+ ********************************************/
+
 if (static_grab (window) == FALSE) return;
+if (static_apply (text, window) == FALSE) return;
 
-/*******************************************
- * modify text data as specified in dialog *
- *******************************************/
+/*************************************************************
+ * when focus object is affected, change it to current layer *
+ *************************************************************/
 
-if (static_apply (text, TRUE, window) == FALSE) return;
+if (focus == TRUE)
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
 
-/*********************************************
- * Redraw gl_area image and reset atom entry *
- *********************************************/
+/*****************************************
+ * redraw gl_area image and reset dialog *
+ *****************************************/
 
 gtk_widget_queue_draw (window->area);
-
-/****************
- * reset dialog *
- ****************/
-
 static_reset (window);
 }
 
