@@ -29,6 +29,26 @@
 #include "gamgi_chem_bond.h"
 #include "gamgi_io_token.h"
 
+enum { STATIC_LAYER, STATIC_LOCAL };
+
+static struct { 
+gamgi_bool local;
+char name[GAMGI_ENGINE_TOKEN];
+int number; } cache;
+
+static void static_default_window (gamgi_window *window)
+{
+gamgi_object *object;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+char string[GAMGI_ENGINE_STRING];
+
+object = GAMGI_CAST_OBJECT window;
+sprintf (string, "%s %d", object->name, object->number);
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
+gtk_entry_set_text (GTK_ENTRY (entry), string);
+}
+
 /**************** internal function ************
  *                                             *
  *                   STATIC_RESET              *
@@ -38,27 +58,38 @@
 static void static_reset (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
-GtkEntry *entry;
+GtkWidget *entry;
+char string[GAMGI_ENGINE_TOKEN];
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_window");
-gtk_entry_set_text (entry, "");
+/*******************************************************
+ * initialize window, name of copies, number of copies *
+ *******************************************************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
+gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_name");
+gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
+sprintf (string, "%d", GAMGI_GTK_COPY_NUMBER);
+gtk_entry_set_text (GTK_ENTRY (entry), string);
 }
 
 /****************** internal function **************
  *                                                 *
- *                    STATIC_GLOBAL                *
+ *                     STATIC_LIST                 *
  *                                                 *
  ***************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *hbox, *button;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_window");
-
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
   /******************************
@@ -66,6 +97,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    ******************************/
 
   gtk_widget_set_sensitive (hbox, TRUE);
+  static_default_window (window);
   }
 else
   {
@@ -78,26 +110,65 @@ else
   }
 }
 
-static void static_copy (gamgi_window *window_mouse, 
-int number, gamgi_window *window_dialog)
+static gamgi_bool static_grab (gamgi_window *window)
 {
-gamgi_window *window;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+const char *name;
+
+/********
+ * name *
+ ********/
+
+cache.name[0] = '\0';
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_name");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  if (gamgi_io_token_alpha_scan (name,
+  cache.name, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid copy name", window);
+    return FALSE;
+    }
+  }
+
+/**********
+ * number *
+ **********/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_int_scan (name, &cache.number, 1, INT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid number data", window);
+  return FALSE;
+  }
+
+return TRUE;
+}
+
+static void static_apply (gamgi_window *window_mouse, gamgi_window *window_dialog)
+{
+gamgi_window *window_new;
 gamgi_layer *layer;
 gamgi_dlist *dlist;
 int i;
 
-/*************************************
- *  copy windows and their contents  *
- *************************************/
+/***********************************
+ * copy windows and their contents *
+ ***********************************/
 
-for (i = 0; i < number; i++)
+for (i = 0; i < cache.number; i++)
   {
-  window = gamgi_engine_copy_window (window_mouse);
+  window_new = gamgi_engine_copy_window (window_mouse);
+  if (cache.name[0] != '\0')
+    strcpy (window_new->object.name, cache.name);
 
-  for (dlist = window->layer_start; dlist != NULL; dlist = dlist->next)
+  for (dlist = window_new->layer_start; dlist != NULL; dlist = dlist->next)
     {
     layer = GAMGI_CAST_LAYER dlist->data;
-    
+
     /**********************************
      * start undo and save mechanisms *
      **********************************/
@@ -108,9 +179,69 @@ for (i = 0; i < number; i++)
     layer->save->data = layer;
     }
 
-  gamgi_gtk_window_create (window, window->layer);
+  gamgi_gtk_window_create (window_new, window_new->layer);
   }
 
+}
+
+static void static_ok_global (gamgi_window *window_dialog)
+{
+gamgi_dlist *dlist;
+
+cache.local = FALSE;
+
+/********************************
+ * get object list, dialog data *
+ ********************************/
+
+if (gamgi->windows == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of window objects", window_dialog); return; }
+
+if (static_grab (window_dialog) == FALSE) return;
+
+/*****************************************
+ * copy windows according to dialog data *
+ ******************************************/
+
+for (dlist = gamgi->windows; dlist != NULL; dlist = dlist->next)
+  static_apply (GAMGI_CAST_WINDOW dlist->data, window_dialog);
+
+/*******************************************
+ * reset the copy dialog in current window *
+ *******************************************/
+
+static_reset (window_dialog);
+}
+
+static void static_ok_local (gamgi_window *window_dialog)
+{
+gamgi_window *window_mouse;
+GtkWidget *dialog = window_dialog->dialog0;
+
+cache.local = TRUE;
+
+/********************************
+ * pick object, get dialog data *
+ ********************************/
+
+window_mouse = GAMGI_CAST_WINDOW gamgi_gtk_object_name_number (dialog,
+"entry_window", GAMGI_ENGINE_WINDOW, window_dialog);
+if (window_mouse == NULL)
+  {
+  gamgi_gtk_dialog_message_create ("Error",
+  "Invalid window object", window_dialog);
+  return;
+  }
+
+if (static_grab (window_dialog) == FALSE) return;
+
+/**********************************************
+ * copy window_mouse according to dialog data *
+ **********************************************/
+
+static_apply (window_mouse, window_dialog);
+
 /*******************************************
  * reset the copy dialog in current window *
  *******************************************/
@@ -126,62 +257,25 @@ static_reset (window_dialog);
 
 static void static_ok (GtkWidget *widget, void *data)
 {
-gamgi_window *window_mouse;
-gamgi_window *window_dialog = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window_dialog->dialog0;
-GtkWidget *entry;
-const char *name;
-int number;
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget* button;
 
-/**************
- * get window *
- **************/
+/*******************************************
+ * copy data: execute global or local task *
+ *******************************************/
 
-window_mouse = GAMGI_CAST_WINDOW gamgi_gtk_object_name_number (dialog,
-"entry_window", GAMGI_ENGINE_WINDOW, window_dialog);
-if (window_mouse == NULL)
-  {
-  gamgi_gtk_dialog_message_create ("Error", 
-  "Invalid Window object", window_dialog);
-  return;
-  }
- 
-/**************
- * get number *
- **************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &number, 1, INT_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", 
-  "Invalid number data", window_dialog);
-  return;
-  }
-
-static_copy (window_mouse, number, window_dialog);
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (window);
+else
+  static_ok_local (window);
 }
 
 static void static_init (gamgi_window *window)
 {
-gamgi_object *object;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *entry;
-char string[2 * GAMGI_ENGINE_TOKEN];
-
-/*********************************
- * initialize: number of copies, *
- * copies destination            *
- *********************************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
-sprintf (string, "%d", GAMGI_GTK_COPY_NUMBER);
-gtk_entry_set_text (GTK_ENTRY (entry), string);
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
-object = GAMGI_CAST_OBJECT window;
-sprintf (string, "%s %d", object->name, object->number);
-gtk_entry_set_text (GTK_ENTRY (entry), string);
+static_reset (window);
+static_list (NULL, window);
 }
 
 static void static_press (gamgi_object *object, void *data)
@@ -216,7 +310,7 @@ const char *name;
  * the second object, not the main object(s)   *
  ***********************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -298,15 +392,15 @@ gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
@@ -319,12 +413,12 @@ gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
-/*************
- * Copy page *
- *************/
+/***************
+ * Object page *
+ ***************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new ("Copies");
+label = gtk_label_new ("Object");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
 gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
@@ -333,24 +427,43 @@ vbox_center = gtk_vbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
 gtk_widget_show (vbox_center);
 
-/**********
- * Number *
- **********/
+/****************
+ * Name, Number *
+ ****************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 5);
+hbox_left = gtk_hbox_new (FALSE, 10);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Number");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+label = gtk_label_new ("Name");
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
+g_object_set_data (G_OBJECT (dialog), "entry_name", entry);
+gtk_widget_show (entry);
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+label = gtk_label_new ("Number");
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_number", entry);
