@@ -13,10 +13,19 @@
  * internal functions *
  **********************
 
+static void static_default_window (gamgi_window *window);
+
 static void static_reset (gamgi_window *window);
 
-static void static_copy (gamgi_window *window_mouse,
-int number, gamgi_window *window_dialog);
+static void static_list (GtkWidget *widget, void *data);
+
+static gamgi_bool static_grab (gamgi_window *window);
+
+static void static_apply (gamgi_window *window_mouse, gamgi_window *window_dialog);
+
+static void static_ok_global (gamgi_window *window_dialog);
+
+static void static_ok_local (gamgi_window *window_dialog);
 
 static void static_ok (GtkWidget *widget, void *data);
 
