@@ -132,7 +132,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 /**************** internal function ************
  *                                             *
- *                  STATIC_GLOBAL              *
+ *                   STATIC_LIST               *
  *                                             *
  * Makes the window entry sensitive when       *
  * the local button is pressed and insensitive *
@@ -140,7 +140,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
  *                                             *
  ***********************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -427,7 +427,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Global");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (button, "toggled", G_CALLBACK (static_global), window);
+g_signal_connect (button, "toggled", G_CALLBACK (static_list), window);
 g_object_set_data (G_OBJECT (dialog), "button_global", button);
 gtk_widget_show (button);
 
