@@ -316,6 +316,12 @@ if (window->timer_progress != 0)
   g_source_remove (window->timer_progress);
 }
 
+void gamgi_gtk_window_remove_window (gamgi_window *window)
+{
+gtk_widget_destroy (GTK_WIDGET (window->window));
+window->window = NULL;
+}
+
 void gamgi_gtk_window_remove_apply (gamgi_window *window)
 {
 /**************************
@@ -329,7 +335,7 @@ gamgi_gtk_window_remove_timers (window);
  * remove Gtk window, Gamgi object *
  ***********************************/
 
-gtk_widget_destroy (GTK_WIDGET (window->window));
+gamgi_gtk_window_remove_window (window);
 gamgi_engine_remove_window (window);
 }
 
