@@ -193,6 +193,75 @@ static_model (gamgi->windows, window);
 static_method (NULL, window);
 }
 
+static gamgi_dlist *static_ok_name (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window)
+{
+gamgi_atom *atom;
+gamgi_dlist *dlist, *dlist_new;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+char name_min[GAMGI_ENGINE_TOKEN] = "";
+char name_max[GAMGI_ENGINE_TOKEN] = "";
+char swap[GAMGI_ENGINE_TOKEN] = "";
+const char *name;
+gamgi_bool condition;
+
+/********************
+ *  * get range limits *
+ *   ********************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "widget_min");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_alpha_scan (name,
+name_min, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid range limits", window);
+  return NULL;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "widget_max");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_alpha_scan (name,
+name_max, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid range limits", window);
+  return NULL;
+  }
+
+if (*name_min != '\0' && *name_max != '\0' && strcmp (name_min, name_max) > 0)
+  {
+  gamgi_gtk_dialog_message_create ("Warning", "Swapped range limits", window);
+
+  strcpy (swap, name_min);
+  strcpy (name_min, name_max);
+  strcpy (name_max, swap);
+  }
+
+/******************************
+ *  * get list of selected atoms *
+ *   ******************************/
+
+dlist_new = NULL;
+for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
+  {
+  atom = GAMGI_CAST_ATOM dlist->data;
+
+  condition = TRUE;
+  if (*name_min != '\0' && strcmp (atom->object.name, name_min) < 0)
+    condition = FALSE;
+  if (*name_max != '\0' && strcmp (atom->object.name, name_max) > 0)
+    condition = FALSE;
+
+  if (condition != action)
+    {
+    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
+    dlist_new->data = atom;
+    }
+  }
+
+return dlist_new;
+}
+
 static void static_ok (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -238,6 +307,9 @@ dlist_old = static_dlist (scope, window);
 if (strcmp (name, "Pick") == 0)
   dlist_new = gamgi_gtk_select_ok_pick (dlist_old, action, window);
 
+else if (strcmp (name, "Name") == 0)
+  dlist_new = static_ok_name (dlist_old, action, window);
+
 else dlist_new = NULL;
 free (name);
 
@@ -618,6 +690,9 @@ tree_store = gtk_tree_store_new (1, G_TYPE_STRING);
 gtk_tree_store_append (tree_store, &iter, NULL);
 gtk_tree_store_set (tree_store, &iter, 0, "Pick", -1);
 
+gtk_tree_store_append (tree_store, &iter, NULL);
+gtk_tree_store_set (tree_store, &iter, 0, "Name", -1);
+
 gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (tree_store));
 g_object_unref (tree_store);
 
