@@ -17,6 +17,7 @@
 #include "gamgi_expat.h"
 #include "gamgi_global.h"
 
+#include "gamgi_engine_list.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_io_token.h"
 
@@ -411,3 +412,29 @@ gamgi_gtk_dialog_message_create ("Error",
 
 return FALSE;
 }
+
+void gamgi_io_error_list (gamgi_slist *start, gamgi_window *window)
+{
+gamgi_object *object;
+gamgi_slist *slist;
+char line[GAMGI_ENGINE_LINE];
+char string[GAMGI_ENGINE_STRING];
+
+if (start == NULL) return;
+
+start = gamgi_engine_slist_invert (start);
+sprintf (line, "The following objects could not be modified:\n");
+for (slist = start; slist != NULL; slist = slist->next)
+  {
+  if (slist != start) strcat (line, ", ");
+  if (strlen (line) > GAMGI_ENGINE_LINE - GAMGI_ENGINE_STRING)
+    { strcat (line, "..."); break; }
+
+  object = GAMGI_CAST_OBJECT slist->data;
+  sprintf (string, "%s %d", object->name, object->number);
+  strcat (line, string);
+  }
+
+gamgi_gtk_dialog_message_create ("Error", line, window);
+gamgi_engine_slist_remove_all (start);
+}
