@@ -64,26 +64,14 @@ GAMGI_PHYS_NODE_211 };
 #define GAMGI_PHYS_CELL_LATTICES 5
 #define GAMGI_PHYS_CELL_GROUPS 230
 
-/***********************
- * default cell origin *
- ***********************/
+/************************************
+ * default cell origin, orientation *
+ ************************************/
 
 #define GAMGI_PHYS_CELL_X 0.0
 #define GAMGI_PHYS_CELL_Y 0.0
 #define GAMGI_PHYS_CELL_Z 0.0
 
-/****************************
- * default node coordinates *
- ****************************/
-
-#define GAMGI_PHYS_NODE_X 0.0
-#define GAMGI_PHYS_NODE_Y 0.0
-#define GAMGI_PHYS_NODE_Z 0.0
-
-/****************************
- * default cell orientation *
- ****************************/
-
 #define GAMGI_PHYS_CELL_E1 0.0
 #define GAMGI_PHYS_CELL_E2 0.0
 #define GAMGI_PHYS_CELL_E3 0.0
@@ -101,6 +89,26 @@ GAMGI_PHYS_NODE_211 };
 #define GAMGI_PHYS_CELL_O2 0
 #define GAMGI_PHYS_CELL_O3 0
 
+/****************************
+ * default node coordinates *
+ ****************************/
+
+#define GAMGI_PHYS_NODE_X 0.0
+#define GAMGI_PHYS_NODE_Y 0.0
+#define GAMGI_PHYS_NODE_Z 0.0
+
+/****************************************
+ * default node shift coordinates, axis *
+ ****************************************/
+ 
+#define GAMGI_PHYS_SHIFT_X 0.0
+#define GAMGI_PHYS_SHIFT_Y 0.0
+#define GAMGI_PHYS_SHIFT_Z 0.0
+
+#define GAMGI_PHYS_SHIFT_U 0
+#define GAMGI_PHYS_SHIFT_V 0
+#define GAMGI_PHYS_SHIFT_W 1
+
 /**************************************
  * Voronoi tesselation:               *
  * 1) array block size                *
