@@ -1428,7 +1428,7 @@ gamgi_engine_darray_push (darray, p3);
 
 gamgi_bool gamgi_phys_plane_cell (gamgi_plane *plane, gamgi_cell *cell)
 {
-gamgi_cell *cell_out;
+gamgi_cell *cell_new;
 gamgi_darray *darray;
 double rotate[9];
 double r1[3], r2[3], r3[3];
@@ -1499,16 +1499,16 @@ else
    * get an array of points describing the    *
    * plane intersection with the cell loops   *
    *                                          *
-   * cell_out is used instead of cell, to     *
-   * ensure that all cell loops are tested    *
+   *  build a new equivalent cell with all    *
+   *  the loops needed to test intersection   *
    *                                          *
    * build default triangle polygon when the  *
    * plane does not intersect the cell volume *
    ********************************************/
 
-  cell_out = gamgi_phys_cell_polygons (cell);
-  darray = gamgi_math_polygon_scan (cell_out->loops, cell_out->points, r1, r2, r3);
-  gamgi_engine_remove_cell (cell_out);
+  cell_new = gamgi_phys_cell_polygons (cell);
+  darray = gamgi_math_polygon_scan (cell_new->loops, cell_new->points, r1, r2, r3);
+  gamgi_engine_remove_cell (cell_new);
   if (darray->offset < 3)
     gamgi_phys_plane_default (r1, r2, r3, &inside, darray);
 
